<?php
require_once '../config.php';

// 处理配送员操作
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['action'])) {
        if ($_POST['action'] === 'add_courier') {
            $name = $_POST['name'] ?? '';
            $phone = $_POST['phone'] ?? '';

            try {
                $stmt = $pdo->prepare("INSERT INTO couriers (name, phone, join_date) VALUES (?, ?, CURRENT_DATE)");
                $stmt->execute([$name, $phone]);
                $success_message = "配送员添加成功";
            } catch (Exception $e) {
                $error_message = "添加配送员失败: " . $e->getMessage();
            }
        } elseif ($_POST['action'] === 'update_courier') {
            $courier_id = $_POST['courier_id'] ?? '';
            $name = $_POST['name'] ?? '';
            $phone = $_POST['phone'] ?? '';
            $status = $_POST['status'] ?? '';

            try {
                $stmt = $pdo->prepare("UPDATE couriers SET name = ?, phone = ?, status = ? WHERE courier_id = ?");
                $stmt->execute([$name, $phone, $status, $courier_id]);
                $success_message = "配送员信息已更新";
            } catch (Exception $e) {
                $error_message = "更新失败: " . $e->getMessage();
            }
        } elseif ($_POST['action'] === 'toggle_active') {
            $courier_id = $_POST['courier_id'] ?? '';
            $is_active = $_POST['is_active'] ?? '0';

            try {
                $stmt = $pdo->prepare("UPDATE couriers SET is_active = ? WHERE courier_id = ?");
                $stmt->execute([$is_active, $courier_id]);
                $success_message = "配送员状态已更新";
            } catch (Exception $e) {
                $error_message = "更新状态失败: " . $e->getMessage();
            }
        }
    }
}

// 获取所有配送员
try {
    $stmt = $pdo->query("SELECT c.*,
                        COUNT(DISTINCT CASE WHEN do.status = '已送达' THEN do.delivery_id END) as completed_orders,
                        AVG(CASE WHEN do.status = '已送达' THEN do.actual_time END) as avg_delivery_time
                        FROM couriers c
                        LEFT JOIN delivery_orders do ON c.courier_id = do.courier_id
                        GROUP BY c.courier_id
                        ORDER BY c.is_active DESC, c.status ASC, c.courier_id ASC");
    $couriers = $stmt->fetchAll();
} catch (Exception $e) {
    $error_message = "获取配送员列表失败: " . $e->getMessage();
    $couriers = [];
}

// 获取配送员统计数据
try {
    $stmt = $pdo->query("SELECT 
                            COUNT(*) as total_couriers,
                            COUNT(CASE WHEN status = '空闲' THEN 1 END) as available_couriers,
                            COUNT(CASE WHEN status = '配送中' THEN 1 END) as busy_couriers,
                            COUNT(CASE WHEN status = '休息' THEN 1 END) as resting_couriers
                        FROM couriers
                        WHERE is_active = 1");
    $courier_stats = $stmt->fetch();
} catch (Exception $e) {
    $error_message = "获取统计数据失败: " . $e->getMessage();
    $courier_stats = [];
}

// 获取今日配送统计
try {
    $stmt = $pdo->query("SELECT 
                            courier_id,
                            COUNT(*) as today_orders,
                            AVG(actual_time) as avg_time,
                            COUNT(CASE WHEN actual_time > estimated_time THEN 1 END) as delayed_orders
                        FROM delivery_orders
                        WHERE DATE(assign_time) = CURRENT_DATE OR DATE(delivery_time) = CURRENT_DATE
                        AND status = '已送达'
                        GROUP BY courier_id");
    $today_stats = [];
    while ($row = $stmt->fetch()) {
        $today_stats[$row['courier_id']] = $row;
    }
} catch (Exception $e) {
    $error_message = "获取今日统计失败: " . $e->getMessage();
    $today_stats = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>配送员管理</title>
    <link rel="stylesheet" href="style.css">
    <style>
        .dashboard {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(200px, 1fr));
            gap: 20px;
            margin-bottom: 30px;
        }

        .stat-card {
            background: #fff;
            border-radius: 8px;
            padding: 20px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            text-align: center;
        }

        .stat-value {
            font-size: 24px;
            font-weight: bold;
            color: #2196F3;
            margin: 10px 0;
        }

        .stat-label {
            color: #666;
            font-size: 14px;
        }

        .courier-grid {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(300px, 1fr));
            gap: 20px;
            margin-bottom: 30px;
        }

        .courier-card {
            background: #fff;
            border-radius: 8px;
            padding: 15px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        }

        .courier-card.inactive {
            opacity: 0.7;
            background: #f5f5f5;
        }

        .courier-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 15px;
            padding-bottom: 10px;
            border-bottom: 1px solid #eee;
        }

        .courier-name {
            font-size: 1.2em;
            font-weight: bold;
        }

        .courier-status {
            padding: 4px 8px;
            border-radius: 4px;
            font-size: 0.9em;
            color: white;
        }

        .status-available {
            background: #4caf50;
        }

        .status-busy {
            background: #ff9800;
        }

        .status-resting {
            background: #9e9e9e;
        }

        .courier-info {
            margin-bottom: 15px;
        }

        .courier-info p {
            margin: 5px 0;
            display: flex;
            justify-content: space-between;
        }

        .courier-actions {
            display: flex;
            gap: 10px;
        }

        .add-courier {
            background: #fff;
            border-radius: 8px;
            padding: 20px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            margin-bottom: 30px;
        }

        .form-row {
            display: flex;
            gap: 15px;
            margin-bottom: 15px;
        }

        .form-group {
            flex: 1;
        }

        .form-control {
            width: 100%;
            padding: 8px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }

        .rating {
            color: #ffc107;
            font-size: 1.2em;
        }

        .today-stats {
            background: #f8f9fa;
            padding: 10px;
            border-radius: 4px;
            margin-top: 10px;
        }

        .today-stats h4 {
            margin: 0 0 10px;
            color: #666;
        }

        .performance-indicator {
            display: inline-block;
            width: 10px;
            height: 10px;
            border-radius: 50%;
            margin-right: 5px;
        }

        .performance-good {
            background: #4caf50;
        }

        .performance-average {
            background: #ff9800;
        }

        .performance-poor {
            background: #f44336;
        }
    </style>
</head>

<body>
    <div class="container">
        <h1>配送员管理</h1>

        <?php if (isset($success_message)): ?>
            <div class="alert alert-success"><?php echo $success_message; ?></div>
        <?php endif; ?>

        <?php if (isset($error_message)): ?>
            <div class="alert alert-danger"><?php echo $error_message; ?></div>
        <?php endif; ?>

        <div class="dashboard">
            <div class="stat-card">
                <div class="stat-value"><?php echo $courier_stats['total_couriers'] ?? 0; ?></div>
                <div class="stat-label">总配送员</div>
            </div>
            <div class="stat-card">
                <div class="stat-value"><?php echo $courier_stats['available_couriers'] ?? 0; ?></div>
                <div class="stat-label">空闲配送员</div>
            </div>
            <div class="stat-card">
                <div class="stat-value"><?php echo $courier_stats['busy_couriers'] ?? 0; ?></div>
                <div class="stat-label">配送中</div>
            </div>
            <div class="stat-card">
                <div class="stat-value"><?php echo $courier_stats['resting_couriers'] ?? 0; ?></div>
                <div class="stat-label">休息中</div>
            </div>
        </div>

        <div class="add-courier">
            <h3>添加新配送员</h3>
            <form method="post" action="">
                <input type="hidden" name="action" value="add_courier">
                <div class="form-row">
                    <div class="form-group">
                        <label>姓名</label>
                        <input type="text" name="name" class="form-control" required>
                    </div>
                    <div class="form-group">
                        <label>电话</label>
                        <input type="text" name="phone" class="form-control" required>
                    </div>
                    <div class="form-group" style="flex: 0 0 auto;">
                        <label>&nbsp;</label>
                        <button type="submit" class="btn btn-primary" style="margin-top: 24px;">添加配送员</button>
                    </div>
                </div>
            </form>
        </div>

        <div class="courier-grid">
            <?php foreach ($couriers as $courier): ?>
                <div class="courier-card <?php echo $courier['is_active'] ? '' : 'inactive'; ?>">
                    <div class="courier-header">
                        <div class="courier-name"><?php echo $courier['name']; ?></div>
                        <div class="courier-status status-<?php echo $courier['status'] === '空闲' ? 'available' : ($courier['status'] === '配送中' ? 'busy' : 'resting'); ?>">
                            <?php echo $courier['status']; ?>
                        </div>
                    </div>

                    <div class="courier-info">
                        <p>
                            <span>电话:</span>
                            <span><?php echo $courier['phone']; ?></span>
                        </p>
                        <p>
                            <span>评分:</span>
                            <span class="rating">
                                <?php echo str_repeat('★', round($courier['rating'])) . str_repeat('☆', 5 - round($courier['rating'])); ?>
                                (<?php echo number_format($courier['rating'], 1); ?>)
                            </span>
                        </p>
                        <p>
                            <span>总完成订单:</span>
                            <span><?php echo $courier['completed_orders']; ?></span>
                        </p>
                        <p>
                            <span>平均配送时间:</span>
                            <span><?php echo $courier['avg_delivery_time'] ? round($courier['avg_delivery_time']) . '分钟' : 'N/A'; ?></span>
                        </p>

                        <?php if (isset($today_stats[$courier['courier_id']])): ?>
                            <div class="today-stats">
                                <h4>今日统计</h4>
                                <p>
                                    <span>完成订单:</span>
                                    <span><?php echo $today_stats[$courier['courier_id']]['today_orders']; ?></span>
                                </p>
                                <p>
                                    <span>平均时间:</span>
                                    <span>
                                        <?php
                                        $avg_time = round($today_stats[$courier['courier_id']]['avg_time']);
                                        echo $avg_time . '分钟';
                                        $performance = $avg_time < 30 ? 'good' : ($avg_time < 45 ? 'average' : 'poor');
                                        ?>
                                        <span class="performance-indicator performance-<?php echo $performance; ?>"></span>
                                    </span>
                                </p>
                                <p>
                                    <span>超时订单:</span>
                                    <span><?php echo $today_stats[$courier['courier_id']]['delayed_orders']; ?></span>
                                </p>
                            </div>
                        <?php endif; ?>
                    </div>

                    <form method="post" action="">
                        <input type="hidden" name="action" value="update_courier">
                        <input type="hidden" name="courier_id" value="<?php echo $courier['courier_id']; ?>">
                        <div class="form-row">
                            <div class="form-group">
                                <select name="status" class="form-control">
                                    <option value="空闲" <?php echo $courier['status'] === '空闲' ? 'selected' : ''; ?>>空闲</option>
                                    <option value="休息" <?php echo $courier['status'] === '休息' ? 'selected' : ''; ?>>休息</option>
                                </select>
                            </div>
                            <div class="form-group" style="flex: 0 0 auto;">
                                <button type="submit" class="btn btn-primary">更新状态</button>
                            </div>
                        </div>
                    </form>

                    <div class="courier-actions">
                        <form method="post" action="" style="display: inline;">
                            <input type="hidden" name="action" value="toggle_active">
                            <input type="hidden" name="courier_id" value="<?php echo $courier['courier_id']; ?>">
                            <input type="hidden" name="is_active" value="<?php echo $courier['is_active'] ? '0' : '1'; ?>">
                            <button type="submit" class="btn <?php echo $courier['is_active'] ? 'btn-warning' : 'btn-success'; ?>">
                                <?php echo $courier['is_active'] ? '停用账号' : '启用账号'; ?>
                            </button>
                        </form>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
    </div>

    <script>
        // 自动刷新页面
        setTimeout(function() {
            location.reload();
        }, 60000); // 每60秒刷新一次
    </script>
</body>

</html>