<?php
require_once '../config.php';

// 创建pickup_notifications表（如果不存在）
try {
    $pdo->exec("CREATE TABLE IF NOT EXISTS pickup_notifications (
        id INT AUTO_INCREMENT PRIMARY KEY,
        order_id VARCHAR(20),
        notification_type ENUM('屏幕显示', '语音播报', '短信', '微信') NOT NULL,
        status ENUM('待通知', '已通知', '已取餐') DEFAULT '待通知',
        create_time DATETIME DEFAULT CURRENT_TIMESTAMP,
        notify_time DATETIME,
        pickup_time DATETIME,
        FOREIGN KEY (order_id) REFERENCES orders(order_id)
    )");
} catch (Exception $e) {
    $error_message = "创建取餐通知表失败: " . $e->getMessage();
}

// 处理叫号操作
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['action']) && $_POST['action'] === 'notify') {
        $order_id = $_POST['order_id'] ?? '';
        $notification_type = $_POST['notification_type'] ?? '屏幕显示';

        try {
            // 添加通知记录
            $stmt = $pdo->prepare("INSERT INTO pickup_notifications (order_id, notification_type, status, notify_time) 
                                  VALUES (?, ?, '已通知', NOW())");
            $stmt->execute([$order_id, $notification_type]);

            // 如果是语音播报，同时添加到voice_alerts表
            if ($notification_type === '语音播报') {
                try {
                    // 确保voice_alerts表存在
                    $pdo->exec("CREATE TABLE IF NOT EXISTS voice_alerts (
                        id INT AUTO_INCREMENT PRIMARY KEY,
                        order_id VARCHAR(20),
                        dish_id INT,
                        status VARCHAR(20),
                        create_time DATETIME DEFAULT CURRENT_TIMESTAMP,
                        is_played TINYINT(1) DEFAULT 0,
                        FOREIGN KEY (order_id) REFERENCES orders(order_id)
                    )");

                    // 添加语音提醒
                    $stmt = $pdo->prepare("INSERT INTO voice_alerts (order_id, status) VALUES (?, '取餐通知')");
                    $stmt->execute([$order_id]);
                } catch (Exception $e) {
                    // 忽略错误，继续执行
                }
            }

            $success_message = "已成功通知顾客取餐";
        } catch (Exception $e) {
            $error_message = "通知失败: " . $e->getMessage();
        }
    } elseif (isset($_POST['action']) && $_POST['action'] === 'mark_pickup') {
        $order_id = $_POST['order_id'] ?? '';

        try {
            // 更新通知状态
            $stmt = $pdo->prepare("UPDATE pickup_notifications SET status = '已取餐', pickup_time = NOW() 
                                  WHERE order_id = ? AND status = '已通知'");
            $stmt->execute([$order_id]);

            $success_message = "已标记为已取餐";
        } catch (Exception $e) {
            $error_message = "更新状态失败: " . $e->getMessage();
        }
    }
}

// 获取已完成但未取餐的订单
try {
    $stmt = $pdo->query("SELECT o.order_id, o.type, o.table_id, o.total_amount, o.create_time, o.payment_time,
                        (SELECT COUNT(*) FROM order_details WHERE order_id = o.order_id) as dish_count,
                        (SELECT MAX(status) FROM pickup_notifications WHERE order_id = o.order_id) as notification_status
                        FROM orders o 
                        WHERE o.status = '已完成'
                        ORDER BY o.payment_time DESC");
    $completed_orders = $stmt->fetchAll();
} catch (Exception $e) {
    $error_message = "获取订单失败: " . $e->getMessage();
    $completed_orders = [];
}

// 获取待取餐的订单（已通知但未取餐）
try {
    $stmt = $pdo->query("SELECT o.order_id, o.type, o.table_id, o.total_amount, o.create_time, 
                        p.notification_type, p.notify_time, p.status as notification_status
                        FROM orders o 
                        JOIN pickup_notifications p ON o.order_id = p.order_id
                        WHERE p.status = '已通知'
                        ORDER BY p.notify_time DESC");
    $notified_orders = $stmt->fetchAll();
} catch (Exception $e) {
    $error_message = "获取通知订单失败: " . $e->getMessage();
    $notified_orders = [];
}

// 获取已取餐的订单历史
try {
    $stmt = $pdo->query("SELECT o.order_id, o.type, o.table_id, o.total_amount, 
                        p.notification_type, p.notify_time, p.pickup_time
                        FROM orders o 
                        JOIN pickup_notifications p ON o.order_id = p.order_id
                        WHERE p.status = '已取餐'
                        ORDER BY p.pickup_time DESC
                        LIMIT 20");
    $pickup_history = $stmt->fetchAll();
} catch (Exception $e) {
    $error_message = "获取取餐历史失败: " . $e->getMessage();
    $pickup_history = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>取餐叫号系统</title>
    <link rel="stylesheet" href="style.css">
    <style>
        .order-grid {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(300px, 1fr));
            gap: 20px;
            margin-bottom: 30px;
        }

        .order-card {
            background: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
            padding: 15px;
            position: relative;
        }

        .order-card.notified {
            background: #e3f2fd;
            border-left: 4px solid #2196F3;
        }

        .order-card.completed {
            background: #fff;
            border-left: 4px solid #4CAF50;
        }

        .order-card.history {
            background: #f5f5f5;
            border-left: 4px solid #9e9e9e;
        }

        .order-header {
            display: flex;
            justify-content: space-between;
            margin-bottom: 10px;
            border-bottom: 1px solid #eee;
            padding-bottom: 10px;
        }

        .order-id {
            font-weight: bold;
            font-size: 1.2em;
        }

        .order-type {
            background: #f0f0f0;
            padding: 3px 8px;
            border-radius: 4px;
            font-size: 0.9em;
        }

        .order-type.dine-in {
            background: #e8f5e9;
            color: #2e7d32;
        }

        .order-type.takeout {
            background: #fff3e0;
            color: #e65100;
        }

        .order-type.delivery {
            background: #e3f2fd;
            color: #0d47a1;
        }

        .order-details {
            margin-bottom: 15px;
        }

        .order-details p {
            margin: 5px 0;
            display: flex;
            justify-content: space-between;
        }

        .order-actions {
            display: flex;
            gap: 10px;
        }

        .notification-badge {
            position: absolute;
            top: 10px;
            right: 10px;
            background: #2196F3;
            color: white;
            padding: 3px 8px;
            border-radius: 4px;
            font-size: 0.8em;
        }

        .section-title {
            margin: 30px 0 15px;
            padding-bottom: 10px;
            border-bottom: 2px solid #eee;
            font-size: 1.5em;
            color: #333;
        }

        .notification-options {
            display: flex;
            gap: 10px;
            margin-bottom: 10px;
        }

        .notification-option {
            padding: 5px 10px;
            background: #f0f0f0;
            border-radius: 4px;
            cursor: pointer;
        }

        .notification-option.active {
            background: #2196F3;
            color: white;
        }

        .time-info {
            font-size: 0.9em;
            color: #666;
            margin-top: 10px;
        }
    </style>
</head>

<body>
    <div class="container">
        <h1>取餐叫号系统</h1>

        <?php if (isset($success_message)): ?>
            <div class="alert alert-success"><?php echo $success_message; ?></div>
        <?php endif; ?>

        <?php if (isset($error_message)): ?>
            <div class="alert alert-danger"><?php echo $error_message; ?></div>
        <?php endif; ?>

        <div class="section-title">待叫号订单</div>
        <div class="order-grid">
            <?php if (empty($completed_orders)): ?>
                <p>当前没有待叫号的订单</p>
            <?php else: ?>
                <?php foreach ($completed_orders as $order): ?>
                    <?php if ($order['notification_status'] !== '已通知' && $order['notification_status'] !== '已取餐'): ?>
                        <div class="order-card completed">
                            <div class="order-header">
                                <div class="order-id"><?php echo $order['order_id']; ?></div>
                                <div class="order-type <?php echo $order['type'] === '堂食' ? 'dine-in' : ($order['type'] === '外带' ? 'takeout' : 'delivery'); ?>">
                                    <?php echo $order['type']; ?>
                                </div>
                            </div>
                            <div class="order-details">
                                <p>
                                    <span>菜品数量:</span>
                                    <span><?php echo $order['dish_count']; ?></span>
                                </p>
                                <p>
                                    <span>总金额:</span>
                                    <span>¥<?php echo number_format($order['total_amount'], 2); ?></span>
                                </p>
                                <p>
                                    <span>完成时间:</span>
                                    <span><?php echo date('H:i:s', strtotime($order['payment_time'])); ?></span>
                                </p>
                            </div>
                            <form method="post" action="">
                                <input type="hidden" name="order_id" value="<?php echo $order['order_id']; ?>">
                                <input type="hidden" name="action" value="notify">
                                <div class="notification-options">
                                    <label class="notification-option active">
                                        <input type="radio" name="notification_type" value="屏幕显示" checked style="display:none;">
                                        屏幕显示
                                    </label>
                                    <label class="notification-option">
                                        <input type="radio" name="notification_type" value="语音播报" style="display:none;">
                                        语音播报
                                    </label>
                                    <label class="notification-option">
                                        <input type="radio" name="notification_type" value="短信" style="display:none;">
                                        短信
                                    </label>
                                    <label class="notification-option">
                                        <input type="radio" name="notification_type" value="微信" style="display:none;">
                                        微信
                                    </label>
                                </div>
                                <div class="order-actions">
                                    <button type="submit" class="btn btn-primary">叫号通知</button>
                                </div>
                            </form>
                        </div>
                    <?php endif; ?>
                <?php endforeach; ?>
            <?php endif; ?>
        </div>

        <div class="section-title">已叫号待取餐</div>
        <div class="order-grid">
            <?php if (empty($notified_orders)): ?>
                <p>当前没有待取餐的订单</p>
            <?php else: ?>
                <?php foreach ($notified_orders as $order): ?>
                    <div class="order-card notified">
                        <div class="notification-badge"><?php echo $order['notification_type']; ?></div>
                        <div class="order-header">
                            <div class="order-id"><?php echo $order['order_id']; ?></div>
                            <div class="order-type <?php echo $order['type'] === '堂食' ? 'dine-in' : ($order['type'] === '外带' ? 'takeout' : 'delivery'); ?>">
                                <?php echo $order['type']; ?>
                            </div>
                        </div>
                        <div class="order-details">
                            <p>
                                <span>总金额:</span>
                                <span>¥<?php echo number_format($order['total_amount'], 2); ?></span>
                            </p>
                            <p>
                                <span>通知时间:</span>
                                <span><?php echo date('H:i:s', strtotime($order['notify_time'])); ?></span>
                            </p>
                            <p>
                                <span>等待时间:</span>
                                <span><?php
                                        $wait_time = time() - strtotime($order['notify_time']);
                                        echo floor($wait_time / 60) . '分' . ($wait_time % 60) . '秒';
                                        ?></span>
                            </p>
                        </div>
                        <form method="post" action="">
                            <input type="hidden" name="order_id" value="<?php echo $order['order_id']; ?>">
                            <input type="hidden" name="action" value="mark_pickup">
                            <div class="order-actions">
                                <button type="submit" class="btn btn-success">标记已取餐</button>
                                <button type="button" class="btn btn-secondary" onclick="renotify('<?php echo $order['order_id']; ?>', '<?php echo $order['notification_type']; ?>')">重新通知</button>
                            </div>
                        </form>
                    </div>
                <?php endforeach; ?>
            <?php endif; ?>
        </div>

        <div class="section-title">取餐历史记录</div>
        <div class="order-grid">
            <?php if (empty($pickup_history)): ?>
                <p>暂无取餐历史记录</p>
            <?php else: ?>
                <?php foreach ($pickup_history as $order): ?>
                    <div class="order-card history">
                        <div class="notification-badge"><?php echo $order['notification_type']; ?></div>
                        <div class="order-header">
                            <div class="order-id"><?php echo $order['order_id']; ?></div>
                            <div class="order-type <?php echo $order['type'] === '堂食' ? 'dine-in' : ($order['type'] === '外带' ? 'takeout' : 'delivery'); ?>">
                                <?php echo $order['type']; ?>
                            </div>
                        </div>
                        <div class="order-details">
                            <p>
                                <span>总金额:</span>
                                <span>¥<?php echo number_format($order['total_amount'], 2); ?></span>
                            </p>
                        </div>
                        <div class="time-info">
                            <p>通知时间: <?php echo date('H:i:s', strtotime($order['notify_time'])); ?></p>
                            <p>取餐时间: <?php echo date('H:i:s', strtotime($order['pickup_time'])); ?></p>
                            <p>等待时长: <?php
                                        $wait_time = strtotime($order['pickup_time']) - strtotime($order['notify_time']);
                                        echo floor($wait_time / 60) . '分' . ($wait_time % 60) . '秒';
                                        ?></p>
                        </div>
                    </div>
                <?php endforeach; ?>
            <?php endif; ?>
        </div>
    </div>

    <script>
        // 通知选项切换
        document.querySelectorAll('.notification-option').forEach(option => {
            option.addEventListener('click', function() {
                const parent = this.closest('.notification-options');
                parent.querySelectorAll('.notification-option').forEach(opt => {
                    opt.classList.remove('active');
                });
                this.classList.add('active');
                this.querySelector('input').checked = true;
            });
        });

        // 重新通知函数
        function renotify(orderId, notificationType) {
            const form = document.createElement('form');
            form.method = 'post';
            form.action = '';

            const orderIdInput = document.createElement('input');
            orderIdInput.type = 'hidden';
            orderIdInput.name = 'order_id';
            orderIdInput.value = orderId;

            const actionInput = document.createElement('input');
            actionInput.type = 'hidden';
            actionInput.name = 'action';
            actionInput.value = 'notify';

            const typeInput = document.createElement('input');
            typeInput.type = 'hidden';
            typeInput.name = 'notification_type';
            typeInput.value = notificationType;

            form.appendChild(orderIdInput);
            form.appendChild(actionInput);
            form.appendChild(typeInput);

            document.body.appendChild(form);
            form.submit();
        }

        // 自动刷新页面
        setTimeout(function() {
            location.reload();
        }, 60000); // 每60秒刷新一次
    </script>
</body>

</html>