<?php
require_once '../config.php';

// 获取所有待处理和进行中的订单
$stmt = $pdo->query("SELECT o.order_id, o.status, o.create_time, 
                     o.type, o.table_id, o.total_amount,
                     (SELECT COUNT(*) FROM order_details WHERE order_id = o.order_id) as dish_count
                     FROM orders o 
                     WHERE o.status IN ('待支付', '进行中')
                     ORDER BY 
                        CASE 
                            WHEN o.type = '堂食' THEN 1
                            WHEN o.type = '外带' THEN 2
                            WHEN o.type = '外卖' THEN 3
                            ELSE 4
                        END,
                        o.create_time ASC");
$orders = $stmt->fetchAll();

// 获取所有菜品类别
$stmt = $pdo->query("SELECT DISTINCT category FROM dishes ORDER BY category");
$categories = $stmt->fetchAll(PDO::FETCH_COLUMN);

// 处理订单状态更新
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action'])) {
    $order_id = $_POST['order_id'] ?? '';
    $dish_id = $_POST['dish_id'] ?? '';
    $new_status = $_POST['new_status'] ?? '';

    try {
        $pdo->beginTransaction();

        if ($_POST['action'] === 'update_dish_status') {
            // 更新订单详情状态
            $stmt = $pdo->prepare("UPDATE order_details SET status = ? WHERE order_id = ? AND dish_id = ?");
            $stmt->execute([$new_status, $order_id, $dish_id]);

            // 检查该订单的所有菜品是否都已完成
            $stmt = $pdo->prepare("SELECT COUNT(*) FROM order_details WHERE order_id = ? AND status != '已完成'");
            $stmt->execute([$order_id]);
            $pending_count = $stmt->fetchColumn();

            // 如果所有菜品都已完成，更新订单状态为已完成
            if ($pending_count == 0) {
                $stmt = $pdo->prepare("UPDATE orders SET status = '已完成' WHERE order_id = ?");
                $stmt->execute([$order_id]);
            } else if ($new_status === '制作中') {
                // 如果有菜品状态变为制作中，更新订单状态为进行中
                $stmt = $pdo->prepare("UPDATE orders SET status = '进行中' WHERE order_id = ?");
                $stmt->execute([$order_id]);
            }

            // 记录状态变更，用于语音播报
            try {
                $stmt = $pdo->prepare("INSERT INTO voice_alerts (order_id, dish_id, status, create_time) VALUES (?, ?, ?, NOW())");
                $stmt->execute([$order_id, $dish_id, $new_status]);
            } catch (Exception $e) {
                // 如果voice_alerts表不存在，忽略错误
            }
        }

        $pdo->commit();

        // 重定向以避免表单重复提交
        header("Location: " . $_SERVER['PHP_SELF']);
        exit;
    } catch (Exception $e) {
        $pdo->rollBack();
        $error_message = "操作失败: " . $e->getMessage();
    }
}
?>

<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <title>后厨显示系统</title>
    <link rel="stylesheet" href="../order_manage/style.css">
    <style>
        body {
            font-family: 'Microsoft YaHei', sans-serif;
            background-color: #f4f6f9;
            margin: 0;
            padding: 20px;
        }

        .kds-container {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(350px, 1fr));
            gap: 20px;
            margin-bottom: 30px;
        }

        .order-card {
            background-color: #fff;
            border-radius: 10px;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
            padding: 15px;
            position: relative;
            border-left: 5px solid #3498db;
        }

        .order-card.urgent {
            border-left-color: #e74c3c;
            background-color: #fff9f9;
        }

        .order-card.in-progress {
            border-left-color: #f39c12;
        }

        .order-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            border-bottom: 1px solid #eee;
            padding-bottom: 10px;
            margin-bottom: 15px;
        }

        .order-id {
            font-size: 18px;
            font-weight: bold;
        }

        .order-time {
            font-size: 14px;
            color: #777;
        }

        .order-type {
            display: inline-block;
            padding: 3px 8px;
            border-radius: 4px;
            font-size: 12px;
            margin-left: 10px;
            color: white;
        }

        .order-type-堂食 {
            background-color: #3498db;
        }

        .order-type-外带 {
            background-color: #e67e22;
        }

        .order-type-外卖 {
            background-color: #9b59b6;
        }

        .order-info {
            margin-bottom: 15px;
        }

        .order-info p {
            margin: 5px 0;
            font-size: 14px;
        }

        .dish-list {
            margin-bottom: 15px;
        }

        .dish-item {
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding: 8px 0;
            border-bottom: 1px dashed #eee;
        }

        .dish-name {
            font-weight: bold;
        }

        .dish-quantity {
            background-color: #f1f1f1;
            padding: 2px 8px;
            border-radius: 12px;
            font-size: 14px;
        }

        .dish-status {
            display: inline-block;
            padding: 3px 8px;
            border-radius: 4px;
            font-size: 12px;
            margin-left: 10px;
        }

        .dish-status-等待中 {
            background-color: #f39c12;
            color: white;
        }

        .dish-status-制作中 {
            background-color: #3498db;
            color: white;
        }

        .dish-status-已完成 {
            background-color: #2ecc71;
            color: white;
        }

        .dish-actions {
            display: flex;
            gap: 10px;
        }

        .btn-action {
            padding: 5px 10px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-size: 12px;
            color: white;
        }

        .btn-start {
            background-color: #3498db;
        }

        .btn-complete {
            background-color: #2ecc71;
        }

        .category-title {
            font-size: 24px;
            font-weight: bold;
            margin: 30px 0 15px;
            padding-bottom: 10px;
            border-bottom: 2px solid #3498db;
            color: #2c3e50;
        }

        .timer {
            position: absolute;
            top: 15px;
            right: 15px;
            font-size: 14px;
            color: #777;
        }

        .timer.warning {
            color: #e74c3c;
            font-weight: bold;
        }

        .controls {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 20px;
        }

        .refresh-control {
            display: flex;
            align-items: center;
        }

        .refresh-control label {
            margin-right: 10px;
        }

        .btn-refresh {
            background-color: #3498db;
            color: white;
            border: none;
            padding: 8px 15px;
            border-radius: 4px;
            cursor: pointer;
        }

        .filter-control {
            display: flex;
            gap: 15px;
        }

        .filter-control label {
            display: flex;
            align-items: center;
        }

        .filter-control input[type="checkbox"] {
            margin-right: 5px;
        }

        .empty-state {
            text-align: center;
            padding: 50px 0;
            color: #7f8c8d;
        }

        .category-section {
            margin-bottom: 30px;
        }

        @media (max-width: 768px) {
            .kds-container {
                grid-template-columns: 1fr;
            }
        }
    </style>
</head>

<body>
    <h1>后厨显示系统 (KDS)</h1>

    <?php if (isset($error_message)): ?>
        <div class="alert error"><?= htmlspecialchars($error_message); ?></div>
    <?php endif; ?>

    <div class="controls">
        <div class="refresh-control">
            <label>
                <input type="checkbox" id="auto-refresh" checked> 自动刷新 (15秒)
            </label>
            <button class="btn-refresh" onclick="location.reload()">立即刷新</button>
        </div>

        <div class="filter-control">
            <label>
                <input type="checkbox" class="filter-type" value="堂食" checked> 堂食
            </label>
            <label>
                <input type="checkbox" class="filter-type" value="外带" checked> 外带
            </label>
            <label>
                <input type="checkbox" class="filter-type" value="外卖" checked> 外卖
            </label>
        </div>
    </div>

    <?php if (empty($orders)): ?>
        <div class="empty-state">
            <h2>当前没有待处理的订单</h2>
            <p>所有订单已完成或尚未有新订单</p>
        </div>
    <?php else: ?>
        <?php foreach ($categories as $category): ?>
            <?php
            // 检查是否有该类别的菜品
            $has_category_dishes = false;
            foreach ($orders as $order) {
                $stmt = $pdo->prepare("SELECT COUNT(*) FROM order_details od 
                                      JOIN dishes d ON od.dish_id = d.dish_id 
                                      WHERE od.order_id = ? AND d.category = ? AND od.status != '已完成'");
                $stmt->execute([$order['order_id'], $category]);
                if ($stmt->fetchColumn() > 0) {
                    $has_category_dishes = true;
                    break;
                }
            }

            if (!$has_category_dishes) continue;
            ?>

            <div class="category-section">
                <h2 class="category-title"><?= htmlspecialchars($category); ?> 区</h2>

                <div class="kds-container">
                    <?php foreach ($orders as $order): ?>
                        <?php
                        // 获取该订单中该类别的菜品
                        $stmt = $pdo->prepare("SELECT od.*, d.name, d.category 
                                              FROM order_details od 
                                              JOIN dishes d ON od.dish_id = d.dish_id 
                                              WHERE od.order_id = ? AND d.category = ? AND od.status != '已完成'
                                              ORDER BY od.status, od.dish_id");
                        $stmt->execute([$order['order_id'], $category]);
                        $dishes = $stmt->fetchAll();

                        if (empty($dishes)) continue;

                        // 计算订单等待时间
                        $create_time = new DateTime($order['create_time']);
                        $now = new DateTime();
                        $wait_time = $now->diff($create_time);
                        $wait_minutes = $wait_time->days * 24 * 60 + $wait_time->h * 60 + $wait_time->i;

                        // 确定订单紧急程度
                        $is_urgent = $wait_minutes >= 15;
                        $order_class = $order['status'] === '制作中' ? 'in-progress' : ($is_urgent ? 'urgent' : '');
                        ?>

                        <div class="order-card <?= $order_class; ?>" data-order-type="<?= htmlspecialchars($order['type']); ?>">
                            <div class="order-header">
                                <div>
                                    <span class="order-id"><?= htmlspecialchars($order['order_id']); ?></span>
                                    <span class="order-type order-type-<?= htmlspecialchars($order['type']); ?>"><?= htmlspecialchars($order['type']); ?></span>
                                </div>
                                <span class="order-time"><?= htmlspecialchars($order['create_time']); ?></span>
                            </div>

                            <div class="timer <?= $is_urgent ? 'warning' : ''; ?>" data-create-time="<?= htmlspecialchars($order['create_time']); ?>">
                                等待: <?= $wait_time->format('%H:%I:%S'); ?>
                            </div>

                            <div class="order-info">
                                <?php if ($order['table_id']): ?>
                                    <p><strong>餐桌号:</strong> <?= htmlspecialchars($order['table_id']); ?></p>
                                <?php endif; ?>
                                <p><strong>菜品数量:</strong> <?= htmlspecialchars($order['dish_count']); ?></p>
                                <p><strong>订单状态:</strong> <span class="dish-status dish-status-<?= htmlspecialchars($order['status']); ?>"><?= htmlspecialchars($order['status']); ?></span></p>
                            </div>

                            <div class="dish-list">
                                <?php foreach ($dishes as $dish): ?>
                                    <div class="dish-item">
                                        <div>
                                            <span class="dish-name"><?= htmlspecialchars($dish['name']); ?></span>
                                            <span class="dish-quantity">x<?= htmlspecialchars($dish['quantity']); ?></span>
                                            <span class="dish-status dish-status-<?= htmlspecialchars($dish['status']); ?>"><?= htmlspecialchars($dish['status']); ?></span>
                                        </div>
                                        <div class="dish-actions">
                                            <form method="post" style="display: inline;">
                                                <input type="hidden" name="action" value="update_dish_status">
                                                <input type="hidden" name="order_id" value="<?= htmlspecialchars($order['order_id']); ?>">
                                                <input type="hidden" name="dish_id" value="<?= htmlspecialchars($dish['dish_id']); ?>">

                                                <?php if ($dish['status'] === '等待中'): ?>
                                                    <input type="hidden" name="new_status" value="制作中">
                                                    <button type="submit" class="btn-action btn-start">开始制作</button>
                                                <?php elseif ($dish['status'] === '制作中'): ?>
                                                    <input type="hidden" name="new_status" value="已完成">
                                                    <button type="submit" class="btn-action btn-complete">完成</button>
                                                <?php endif; ?>
                                            </form>
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        <?php endforeach; ?>
    <?php endif; ?>

    <script>
        // 自动刷新功能
        let refreshInterval;
        const toggleCheckbox = document.getElementById('auto-refresh');

        function startAutoRefresh() {
            refreshInterval = setInterval(function() {
                location.reload();
            }, 15000); // 15秒刷新一次
        }

        function stopAutoRefresh() {
            clearInterval(refreshInterval);
        }

        toggleCheckbox.addEventListener('change', function() {
            if (this.checked) {
                startAutoRefresh();
            } else {
                stopAutoRefresh();
            }
        });

        // 初始化自动刷新
        if (toggleCheckbox.checked) {
            startAutoRefresh();
        }

        // 实时更新等待时间
        function updateTimers() {
            const timers = document.querySelectorAll('.timer');

            timers.forEach(timer => {
                const createTime = new Date(timer.getAttribute('data-create-time'));
                const now = new Date();
                const diffMs = now - createTime;

                // 计算时、分、秒
                const diffHrs = Math.floor(diffMs / 3600000);
                const diffMins = Math.floor((diffMs % 3600000) / 60000);
                const diffSecs = Math.floor((diffMs % 60000) / 1000);

                // 格式化显示
                const formattedTime =
                    (diffHrs < 10 ? '0' + diffHrs : diffHrs) + ':' +
                    (diffMins < 10 ? '0' + diffMins : diffMins) + ':' +
                    (diffSecs < 10 ? '0' + diffSecs : diffSecs);

                timer.textContent = '等待: ' + formattedTime;

                // 15分钟以上显示警告
                if (diffMs >= 15 * 60 * 1000) {
                    timer.classList.add('warning');
                }
            });
        }

        // 每秒更新一次计时器
        setInterval(updateTimers, 1000);

        // 初始化更新计时器
        updateTimers();

        // 订单类型筛选
        const typeFilters = document.querySelectorAll('.filter-type');

        function applyFilters() {
            const selectedTypes = Array.from(typeFilters)
                .filter(checkbox => checkbox.checked)
                .map(checkbox => checkbox.value);

            const orderCards = document.querySelectorAll('.order-card');

            orderCards.forEach(card => {
                const orderType = card.getAttribute('data-order-type');
                if (selectedTypes.includes(orderType)) {
                    card.style.display = '';
                } else {
                    card.style.display = 'none';
                }
            });
        }

        typeFilters.forEach(filter => {
            filter.addEventListener('change', applyFilters);
        });
    </script>
</body>

</html>