<?php
session_start();
require_once '../config.php';

// 权限验证
if (!isset($_SESSION['employee_id'])) {
    header("Location: ../login.php");
    exit;
}

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $type = $_POST['type'] ?? '';
    $discount_amount = (float)($_POST['discount_amount'] ?? 0);
    $min_amount = (float)($_POST['min_amount'] ?? 0);
    $start_date = $_POST['start_date'] ?? date('Y-m-d');
    $end_date = $_POST['end_date'] ?? date('Y-m-d', strtotime('+30 days'));
    $target_type = $_POST['target_type'] ?? 'all';
    $level = (int)($_POST['level'] ?? 0);
    $user_id = (int)($_POST['user_id'] ?? 0);

    // 验证数据
    if (!in_array($type, ['满减', '折扣', '赠品'])) {
        $_SESSION['error'] = "无效的优惠券类型";
        header("Location: coupon_management.php");
        exit;
    }

    if ($discount_amount <= 0) {
        $_SESSION['error'] = "优惠金额/折扣率必须大于0";
        header("Location: coupon_management.php");
        exit;
    }

    if ($min_amount < 0) {
        $_SESSION['error'] = "最低消费金额不能为负数";
        header("Location: coupon_management.php");
        exit;
    }

    if (strtotime($end_date) < strtotime($start_date)) {
        $_SESSION['error'] = "结束日期不能早于开始日期";
        header("Location: coupon_management.php");
        exit;
    }

    try {
        $pdo->beginTransaction();

        // 根据目标类型获取用户列表
        $user_ids = [];

        if ($target_type === 'specific' && $user_id > 0) {
            // 指定会员
            $user_ids[] = $user_id;
        } else if ($target_type === 'level' && $level > 0) {
            // 指定等级会员
            $stmt = $pdo->prepare("
                SELECT user_id FROM members WHERE level = ?
            ");
            $stmt->execute([$level]);
            while ($row = $stmt->fetch()) {
                $user_ids[] = $row['user_id'];
            }
        } else {
            // 所有会员
            $stmt = $pdo->query("SELECT user_id FROM members");
            while ($row = $stmt->fetch()) {
                $user_ids[] = $row['user_id'];
            }
        }

        // 创建优惠券
        $created_count = 0;
        foreach ($user_ids as $uid) {
            // 生成优惠券ID - 确保长度不超过20个字符
            // 使用年月日时分秒格式 (YmdHis) 而不是完整的年月日时分秒
            $coupon_id = 'CPN' . date('ymdHis') . rand(100, 999);

            $stmt = $pdo->prepare("
                INSERT INTO coupons (
                    coupon_id, 
                    user_id, 
                    type, 
                    discount_amount, 
                    min_amount, 
                    start_date, 
                    end_date, 
                    status
                ) VALUES (?, ?, ?, ?, ?, ?, ?, '未使用')
            ");

            $stmt->execute([
                $coupon_id,
                $uid,
                $type,
                $discount_amount,
                $min_amount,
                $start_date,
                $end_date
            ]);

            $created_count++;
        }

        $pdo->commit();

        // 记录日志
        log_action('action', '创建优惠券', "创建{$created_count}张优惠券，类型: $type", 'create');

        $_SESSION['success'] = "成功创建{$created_count}张优惠券";
    } catch (Exception $e) {
        $pdo->rollBack();
        $_SESSION['error'] = "优惠券创建失败: " . $e->getMessage();
    }

    header("Location: coupon_management.php");
    exit;
}

// 如果不是POST请求，重定向回优惠券管理页面
header("Location: coupon_management.php");
exit;
