<?php
session_start();
require_once '../config.php';

// 权限验证
if (!isset($_SESSION['employee_id'])) {
    header("Location: ../login.php");
    exit;
}

// 删除优惠券
if (isset($_GET['delete'])) {
    $coupon_id = $_GET['delete'];

    try {
        $pdo->beginTransaction();

        // 删除优惠券
        $stmt = $pdo->prepare("DELETE FROM coupons WHERE coupon_id = ? AND status = '未使用'");
        $stmt->execute([$coupon_id]);

        if ($stmt->rowCount() > 0) {
            $_SESSION['success'] = "优惠券删除成功";
            log_action('action', '删除优惠券', "删除优惠券ID: $coupon_id", 'delete');
        } else {
            $_SESSION['error'] = "无法删除已使用或已过期的优惠券";
        }

        $pdo->commit();
    } catch (PDOException $e) {
        $pdo->rollBack();
        $_SESSION['error'] = "删除失败：" . $e->getMessage();
    }
    header("Location: coupon_management.php");
    exit;
}

// 获取所有优惠券
$coupons = $pdo->query("
    SELECT 
        c.coupon_id,
        c.user_id,
        u.phone,
        c.type,
        c.discount_amount,
        c.min_amount,
        DATE_FORMAT(c.start_date, '%Y-%m-%d') AS start_date,
        DATE_FORMAT(c.end_date, '%Y-%m-%d') AS end_date,
        c.status
    FROM coupons c
    LEFT JOIN users u ON c.user_id = u.user_id
    ORDER BY c.start_date DESC, c.status
")->fetchAll();

// 获取所有会员
$members = $pdo->query("
    SELECT 
        m.member_id,
        u.user_id,
        u.phone,
        m.level
    FROM members m
    JOIN users u ON m.user_id = u.user_id
    ORDER BY m.level DESC, u.phone
")->fetchAll();

// 优惠券类型映射
$couponTypeMap = [
    '满减' => '满减券',
    '折扣' => '折扣券',
    '赠品' => '赠品券'
];

// 优惠券状态映射
$statusMap = [
    '未使用' => '<span class="status-tag available">未使用</span>',
    '已使用' => '<span class="status-tag used">已使用</span>',
    '已过期' => '<span class="status-tag expired">已过期</span>'
];

// 会员等级映射
$levelMap = [
    1 => '普通会员',
    2 => '银卡会员',
    3 => '金卡会员',
    4 => '钻石会员'
];
?>

<!DOCTYPE html>
<html>

<head>
    <title>优惠券管理</title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h2>优惠券管理系统</h2>

        <!-- 消息提示 -->
        <?php if (isset($_SESSION['success'])): ?>
            <div class="alert success"><?= $_SESSION['success'] ?></div>
            <?php unset($_SESSION['success']); ?>
        <?php endif; ?>

        <?php if (isset($_SESSION['error'])): ?>
            <div class="alert error"><?= $_SESSION['error'] ?></div>
            <?php unset($_SESSION['error']); ?>
        <?php endif; ?>

        <!-- 创建优惠券表单 -->
        <div class="card">
            <h3>创建优惠券</h3>
            <form method="POST" action="coupon_create.php">
                <div class="form-group">
                    <label>优惠券类型</label>
                    <select name="type" required id="couponType">
                        <option value="满减">满减券</option>
                        <option value="折扣">折扣券</option>
                        <option value="赠品">赠品券</option>
                    </select>
                </div>

                <div class="form-group" id="discountAmountGroup">
                    <label>优惠金额/折扣率</label>
                    <input type="number" name="discount_amount" step="0.01" min="0" required>
                    <small id="discountHint">满减券：直接输入金额，如20表示减20元；折扣券：输入折扣率，如8.5表示8.5折</small>
                </div>

                <div class="form-group">
                    <label>最低消费金额</label>
                    <input type="number" name="min_amount" step="0.01" min="0" value="0">
                    <small>0表示无最低消费限制</small>
                </div>

                <div class="form-group">
                    <label>有效期开始</label>
                    <input type="date" name="start_date" required value="<?= date('Y-m-d') ?>">
                </div>

                <div class="form-group">
                    <label>有效期结束</label>
                    <input type="date" name="end_date" required value="<?= date('Y-m-d', strtotime('+30 days')) ?>">
                </div>

                <div class="form-group">
                    <label>发放对象</label>
                    <select name="target_type" id="targetType">
                        <option value="all">所有会员</option>
                        <option value="level">指定等级会员</option>
                        <option value="specific">指定会员</option>
                    </select>
                </div>

                <div class="form-group" id="levelGroup" style="display:none;">
                    <label>会员等级</label>
                    <select name="level">
                        <?php foreach ($levelMap as $value => $label): ?>
                            <option value="<?= $value ?>"><?= $label ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <div class="form-group" id="memberGroup" style="display:none;">
                    <label>选择会员</label>
                    <select name="user_id">
                        <?php foreach ($members as $member): ?>
                            <option value="<?= $member['user_id'] ?>">
                                <?= htmlspecialchars($member['phone']) ?>
                                (<?= $levelMap[$member['level']] ?>)
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <button type="submit" class="btn-primary">创建优惠券</button>
            </form>
        </div>

        <!-- 优惠券列表 -->
        <div class="card">
            <h3>优惠券列表</h3>
            <table class="data-table">
                <thead>
                    <tr>
                        <th>优惠券ID</th>
                        <th>用户手机</th>
                        <th>类型</th>
                        <th>优惠金额/折扣</th>
                        <th>最低消费</th>
                        <th>有效期</th>
                        <th>状态</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($coupons as $coupon): ?>
                        <tr>
                            <td><?= $coupon['coupon_id'] ?></td>
                            <td><?= htmlspecialchars($coupon['phone'] ?? '未分配') ?></td>
                            <td><?= $couponTypeMap[$coupon['type']] ?? $coupon['type'] ?></td>
                            <td>
                                <?php if ($coupon['type'] == '满减'): ?>
                                    ¥<?= number_format($coupon['discount_amount'], 2) ?>
                                <?php elseif ($coupon['type'] == '折扣'): ?>
                                    <?= $coupon['discount_amount'] ?>折
                                <?php else: ?>
                                    <?= $coupon['discount_amount'] ?>
                                <?php endif; ?>
                            </td>
                            <td><?= $coupon['min_amount'] > 0 ? '¥' . number_format($coupon['min_amount'], 2) : '无限制' ?></td>
                            <td><?= $coupon['start_date'] ?> 至 <?= $coupon['end_date'] ?></td>
                            <td><?= $statusMap[$coupon['status']] ?? $coupon['status'] ?></td>
                            <td>
                                <?php if ($coupon['status'] == '未使用'): ?>
                                    <a href="coupon_management.php?delete=<?= $coupon['coupon_id'] ?>"
                                        onclick="return confirm('确认删除该优惠券？')"
                                        class="btn-delete">删除</a>
                                <?php endif; ?>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>

    <script>
        // 动态显示表单字段
        document.addEventListener('DOMContentLoaded', function() {
            const targetType = document.getElementById('targetType');
            const levelGroup = document.getElementById('levelGroup');
            const memberGroup = document.getElementById('memberGroup');

            targetType.addEventListener('change', function() {
                if (this.value === 'level') {
                    levelGroup.style.display = 'block';
                    memberGroup.style.display = 'none';
                } else if (this.value === 'specific') {
                    levelGroup.style.display = 'none';
                    memberGroup.style.display = 'block';
                } else {
                    levelGroup.style.display = 'none';
                    memberGroup.style.display = 'none';
                }
            });

            const couponType = document.getElementById('couponType');
            const discountHint = document.getElementById('discountHint');

            couponType.addEventListener('change', function() {
                if (this.value === '满减') {
                    discountHint.textContent = '满减券：直接输入金额，如20表示减20元';
                } else if (this.value === '折扣') {
                    discountHint.textContent = '折扣券：输入折扣率，如8.5表示8.5折';
                } else {
                    discountHint.textContent = '赠品券：输入赠品描述或代码';
                }
            });
        });
    </script>
</body>

</html>