<?php
session_start();
require_once '../config.php';

// 权限验证
if (!isset($_SESSION['employee_id'])) {
    header("Location: ../login.php");
    exit;
}

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $phone = $_POST['phone'] ?? '';
    $wechat_id = $_POST['wechat_id'] ?? null;
    $level = (int)($_POST['level'] ?? 1);
    $points = (int)($_POST['points'] ?? 0);

    // 验证手机号
    if (!preg_match('/^1[3-9]\d{9}$/', $phone)) {
        $_SESSION['error'] = "手机号格式不正确";
        header("Location: member_management.php");
        exit;
    }

    try {
        $pdo->beginTransaction();

        // 检查手机号是否已存在
        $stmt = $pdo->prepare("SELECT user_id FROM users WHERE phone = ?");
        $stmt->execute([$phone]);
        $user_id = $stmt->fetchColumn();

        if (!$user_id) {
            // 创建新用户
            $stmt = $pdo->prepare("
                INSERT INTO users (phone, wechat_id, reg_date)
                VALUES (?, ?, NOW())
            ");
            $stmt->execute([$phone, $wechat_id]);
            $user_id = $pdo->lastInsertId();
        } else {
            // 更新现有用户的微信ID（如果提供）
            if ($wechat_id) {
                $stmt = $pdo->prepare("
                    UPDATE users SET wechat_id = ? WHERE user_id = ?
                ");
                $stmt->execute([$wechat_id, $user_id]);
            }

            // 检查用户是否已经是会员
            $stmt = $pdo->prepare("SELECT member_id FROM members WHERE user_id = ?");
            $stmt->execute([$user_id]);
            if ($stmt->fetchColumn()) {
                throw new Exception("该手机号已注册为会员");
            }
        }

        // 创建会员记录
        $stmt = $pdo->prepare("
            INSERT INTO members (member_id, user_id, level, points, join_date)
            VALUES (?, ?, ?, ?, NOW())
        ");
        $stmt->execute([$user_id, $user_id, $level, $points]);

        $pdo->commit();

        // 记录日志
        log_action('action', '创建会员', "创建会员ID: $user_id, 手机号: $phone", 'create');

        $_SESSION['success'] = "会员创建成功";
    } catch (Exception $e) {
        $pdo->rollBack();
        $_SESSION['error'] = "会员创建失败: " . $e->getMessage();
    }

    header("Location: member_management.php");
    exit;
}

// 如果不是POST请求，重定向回会员管理页面
header("Location: member_management.php");
exit;
