<?php
session_start();
require_once '../config.php';

// 权限验证
if (!isset($_SESSION['employee_id'])) {
    header("Location: ../login.php");
    exit;
}

// 删除会员
if (isset($_GET['delete'])) {
    $member_id = (int)$_GET['delete'];

    try {
        $pdo->beginTransaction();

        // 先获取用户ID
        $stmt = $pdo->prepare("SELECT user_id FROM members WHERE member_id = ?");
        $stmt->execute([$member_id]);
        $user_id = $stmt->fetchColumn();

        // 删除会员记录
        $pdo->prepare("DELETE FROM members WHERE member_id = ?")
            ->execute([$member_id]);

        $pdo->commit();
        $_SESSION['success'] = "会员删除成功";
        log_action('action', '删除会员', "删除会员ID: $member_id", 'delete');
    } catch (PDOException $e) {
        $pdo->rollBack();
        $_SESSION['error'] = "删除失败：" . $e->getMessage();
    }
    header("Location: member_management.php");
    exit;
}

// 获取所有会员
$members = $pdo->query("
    SELECT 
        m.member_id,
        u.phone,
        u.wechat_id,
        m.level,
        m.points,
        DATE_FORMAT(m.join_date, '%Y-%m-%d') AS join_date,
        DATE_FORMAT(u.last_login, '%Y-%m-%d %H:%i') AS last_login
    FROM members m
    JOIN users u ON m.user_id = u.user_id
    ORDER BY m.level DESC, m.points DESC
")->fetchAll();

// 会员等级映射
$levelMap = [
    1 => '普通会员',
    2 => '银卡会员',
    3 => '金卡会员',
    4 => '钻石会员'
];
?>

<!DOCTYPE html>
<html>

<head>
    <title>会员管理</title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h2>会员管理系统</h2>

        <!-- 消息提示 -->
        <?php if (isset($_SESSION['success'])): ?>
            <div class="alert success"><?= $_SESSION['success'] ?></div>
            <?php unset($_SESSION['success']); ?>
        <?php endif; ?>

        <?php if (isset($_SESSION['error'])): ?>
            <div class="alert error"><?= $_SESSION['error'] ?></div>
            <?php unset($_SESSION['error']); ?>
        <?php endif; ?>

        <!-- 新建会员表单 -->
        <div class="card">
            <h3>新建会员</h3>
            <form method="POST" action="member_create.php">
                <div class="form-group">
                    <label>手机号</label>
                    <input type="text" name="phone" required
                        pattern="1[3-9]\d{9}"
                        title="请输入正确的手机号码">
                </div>

                <div class="form-group">
                    <label>微信ID（选填）</label>
                    <input type="text" name="wechat_id">
                </div>

                <div class="form-group">
                    <label>会员等级</label>
                    <select name="level" required>
                        <?php foreach ($levelMap as $value => $label): ?>
                            <option value="<?= $value ?>"><?= $label ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <div class="form-group">
                    <label>初始积分</label>
                    <input type="number" name="points" value="0" min="0">
                </div>

                <button type="submit" class="btn-primary">创建会员</button>
            </form>
        </div>

        <!-- 会员列表 -->
        <div class="card">
            <h3>会员列表</h3>
            <table class="data-table">
                <thead>
                    <tr>
                        <th>会员ID</th>
                        <th>手机号</th>
                        <th>微信ID</th>
                        <th>会员等级</th>
                        <th>积分</th>
                        <th>注册日期</th>
                        <th>最后登录</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($members as $member): ?>
                        <tr>
                            <td><?= $member['member_id'] ?></td>
                            <td><?= htmlspecialchars($member['phone']) ?></td>
                            <td><?= htmlspecialchars($member['wechat_id'] ?? '未绑定') ?></td>
                            <td><?= $levelMap[$member['level']] ?? '未知等级' ?></td>
                            <td><?= $member['points'] ?></td>
                            <td><?= $member['join_date'] ?></td>
                            <td>
                                <?= $member['last_login'] ?: '从未登录' ?>
                            </td>
                            <td>
                                <a href="member_edit.php?id=<?= $member['member_id'] ?>"
                                    class="btn-edit">编辑</a>
                                <a href="member_management.php?delete=<?= $member['member_id'] ?>"
                                    onclick="return confirm('确认删除该会员？这将删除所有相关数据！')"
                                    class="btn-delete">删除</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</body>

</html>