<?php
session_start();
require_once '../config.php';

// 权限验证
if (!isset($_SESSION['employee_id'])) {
    header("Location: ../login.php");
    exit;
}

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $referrer_id = (int)($_POST['referrer_id'] ?? 0);
    $referred_id = (int)($_POST['referred_id'] ?? 0);

    // 验证数据
    if ($referrer_id <= 0 || $referred_id <= 0) {
        $_SESSION['error'] = "无效的会员ID";
        header("Location: referral_program.php");
        exit;
    }

    if ($referrer_id == $referred_id) {
        $_SESSION['error'] = "推荐人和被推荐人不能是同一人";
        header("Location: referral_program.php");
        exit;
    }

    try {
        $pdo->beginTransaction();

        // 检查是否已存在相同的推荐记录
        $stmt = $pdo->prepare("
            SELECT COUNT(*) FROM referrals 
            WHERE referrer_id = ? AND referred_id = ?
        ");
        $stmt->execute([$referrer_id, $referred_id]);

        if ($stmt->fetchColumn() > 0) {
            throw new Exception("该推荐记录已存在");
        }

        // 创建推荐记录
        $stmt = $pdo->prepare("
            INSERT INTO referrals (
                referrer_id,
                referred_id,
                status,
                created_at
            ) VALUES (?, ?, '待消费', NOW())
        ");

        $stmt->execute([$referrer_id, $referred_id]);
        $referral_id = $pdo->lastInsertId();

        $pdo->commit();

        // 记录日志
        log_action('action', '创建推荐记录', "推荐ID: $referral_id, 推荐人: $referrer_id, 被推荐人: $referred_id", 'create');

        $_SESSION['success'] = "推荐记录创建成功";
    } catch (Exception $e) {
        $pdo->rollBack();
        $_SESSION['error'] = "推荐记录创建失败: " . $e->getMessage();
    }

    header("Location: referral_program.php");
    exit;
}

// 如果不是POST请求，重定向回推荐计划页面
header("Location: referral_program.php");
exit;
