<?php
require '../config.php';

// 获取所有可用菜品（库存大于 0）
$stmt = $pdo->query("SELECT dish_id, name, price, stock FROM dishes WHERE stock > 0 ORDER BY name");
$dishes = $stmt->fetchAll();

// 获取所有空闲的餐桌
$stmt = $pdo->query("SELECT table_id FROM dining_tables WHERE status = '空闲' ORDER BY table_id");
$tables = $stmt->fetchAll();

// 获取所有会员信息
$stmt = $pdo->query("SELECT m.member_id, m.level, u.phone 
                     FROM members m 
                     JOIN users u ON m.user_id = u.user_id 
                     ORDER BY m.member_id");
$members = $stmt->fetchAll();

$message = "";

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $table_id = $_POST['table_id'] ?? null;
    $member_id = $_POST['member_id'] ?? null;
    $items = $_POST['items'] ?? [];
    $order_type = $_POST['order_type'] ?? '堂食';
    $payment_method = $_POST['payment_method'] ?? '';
    $address = ($order_type === '外卖') ? ($_POST['address'] ?? '') : '';
    $remark = $_POST['remark'] ?? '';

    // 验证必填字段
    if (empty($items)) {
        $message = "<div class='alert alert-danger'>请至少选择一道菜品</div>";
    } else if ($order_type === '堂食' && !$table_id) {
        $message = "<div class='alert alert-danger'>堂食请选择餐桌</div>";
    } else if ($order_type === '外卖' && empty($address)) {
        $message = "<div class='alert alert-danger'>外卖请填写配送地址</div>";
    } else {
        try {
            $pdo->beginTransaction();

            // 生成唯一订单ID
            $order_id = date('YmdHis') . rand(1000, 9999);

            // 计算订单总价
            $total_amount = 0;
            foreach ($items as $dish_id => $qty) {
                if ($qty > 0) {
                    $stmt = $pdo->prepare("SELECT price FROM dishes WHERE dish_id = ?");
                    $stmt->execute([$dish_id]);
                    $dish = $stmt->fetch();
                    $total_amount += $dish['price'] * $qty;
                }
            }

            // 创建订单
            if ($order_type === '堂食') {
                $stmt = $pdo->prepare("INSERT INTO orders (order_id, user_id, table_id, type, status, total_amount, create_time, remark) VALUES (?, ?, ?, ?, '待支付', ?, NOW(), ?)");
                $stmt->execute([$order_id, $member_id, $table_id, $order_type, $total_amount, $remark]);

                // 更新餐桌状态为用餐中
                $stmt = $pdo->prepare("UPDATE dining_tables SET status = '用餐中' WHERE table_id = ?");
                $stmt->execute([$table_id]);
            } else {
                $stmt = $pdo->prepare("INSERT INTO orders (order_id, user_id, type, status, total_amount, create_time, remark) VALUES (?, ?, ?, '待支付', ?, NOW(), ?)");
                $stmt->execute([$order_id, $member_id, $order_type, $total_amount, $remark]);
            }

            // 创建订单详情并更新库存
            foreach ($items as $dish_id => $qty) {
                if ($qty > 0) {
                    $stmt = $pdo->prepare("SELECT price FROM dishes WHERE dish_id = ?");
                    $stmt->execute([$dish_id]);
                    $dish = $stmt->fetch();

                    $stmt = $pdo->prepare("INSERT INTO order_details (order_id, dish_id, quantity, price, status) VALUES (?, ?, ?, ?, '等待中')");
                    $stmt->execute([$order_id, $dish_id, $qty, $dish['price']]);

                    // 更新库存
                    $stmt = $pdo->prepare("UPDATE dishes SET stock = stock - ? WHERE dish_id = ?");
                    $stmt->execute([$qty, $dish_id]);
                }
            }

            // 同步订单到厨房
            $stmt = $pdo->prepare("INSERT INTO kitchen_orders (order_id, status, create_time) VALUES (?, '待处理', NOW())");
            $stmt->execute([$order_id]);

            $pdo->commit();

            $log_message = "订单ID: $order_id, 订单类型: $order_type";
            if ($order_type === '堂食') {
                $log_message .= ", 餐桌ID: $table_id";
            } else if ($order_type === '外卖') {
                $log_message .= ", 配送地址: $address";
            }
            if ($member_id) {
                $log_message .= ", 会员ID: $member_id";
            }
            log_action('订单', '前台点单', $log_message);

            $message = "<div class='alert alert-success'>订单已创建成功！订单号: $order_id</div>";

            // 不再重定向到支付页面，而是留在当前页面
            // header("Location: payment.php?order_id=$order_id");
            // exit;
        } catch (Exception $e) {
            $pdo->rollBack();
            $message = "<div class='alert alert-danger'>提交失败: " . htmlspecialchars($e->getMessage()) . "</div>";
        }
    }
}
?>
<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <title>前台点单</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        /* 单选按钮与标签对齐的样式 */
        .radio-group {
            display: flex;
            align-items: center;
            margin-bottom: 10px;
        }

        .radio-group label {
            display: flex;
            align-items: center;
            margin-right: 15px;
        }

        .radio-group input[type="radio"] {
            margin-right: 5px;
            vertical-align: middle;
        }

        .option-label {
            display: block;
            margin-bottom: 8px;
            font-weight: bold;
        }

        .dish-category {
            margin-top: 20px;
            border-bottom: 1px solid #ddd;
            padding-bottom: 10px;
        }

        .order-summary {
            background: #f9f9f9;
            padding: 15px;
            border-radius: 5px;
            margin-top: 20px;
        }

        .order-summary h3 {
            margin-top: 0;
        }

        .counter-layout {
            display: grid;
            grid-template-columns: 2fr 1fr;
            gap: 20px;
        }

        .dish-search {
            margin-bottom: 15px;
        }

        .dish-search input {
            width: 100%;
            padding: 8px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }

        .container {
            height: 100vh;
            /* 固定高度为视口高度 */
            overflow-y: auto;
            /* 添加垂直滚动条 */
        }
    </style>
    <script>
        // 切换订单类型的显示
        function toggleOrderType() {
            var orderType = document.querySelector('input[name="order_type"]:checked').value;
            var tableDiv = document.getElementById('table_id_div');
            var addressDiv = document.getElementById('address_div');

            if (orderType === '堂食') {
                tableDiv.style.display = 'block';
                addressDiv.style.display = 'none';
            } else if (orderType === '外卖') {
                tableDiv.style.display = 'none';
                addressDiv.style.display = 'block';
            } else { // 外带
                tableDiv.style.display = 'none';
                addressDiv.style.display = 'none';
            }
        }

        // 计算总价
        function calculateTotal() {
            var total = 0;
            var inputs = document.querySelectorAll('input[name^="items["]');

            inputs.forEach(function(input) {
                var qty = parseInt(input.value) || 0;
                if (qty > 0) {
                    var price = parseFloat(input.getAttribute('data-price'));
                    total += qty * price;
                }
            });

            document.getElementById('total_amount').textContent = total.toFixed(2);
        }

        // 搜索菜品
        function searchDishes() {
            var searchTerm = document.getElementById('dish_search').value.toLowerCase();
            var dishes = document.querySelectorAll('.dish-card');

            dishes.forEach(function(dish) {
                var dishName = dish.querySelector('strong').textContent.toLowerCase();
                if (dishName.includes(searchTerm) || searchTerm === '') {
                    dish.style.display = 'block';
                } else {
                    dish.style.display = 'none';
                }
            });
        }

        window.onload = function() {
            toggleOrderType();
            calculateTotal();

            // 为所有数量输入框添加事件监听器
            var inputs = document.querySelectorAll('input[name^="items["]');
            inputs.forEach(function(input) {
                input.addEventListener('change', calculateTotal);
            });
        };
    </script>
</head>

<body>
    <div class="container">
        <h2>前台点单</h2>
        <?= $message; ?>

        <form method="post">
            <?= csrf_field(); ?>

            <div class="counter-layout">
                <div class="left-column">
                    <div class="form-group">
                        <label class="option-label">订单类型</label>
                        <div class="radio-group">
                            <label><input type="radio" name="order_type" value="堂食" onclick="toggleOrderType()" checked> 堂食</label>
                            <label><input type="radio" name="order_type" value="外带" onclick="toggleOrderType()"> 外带</label>
                            <label><input type="radio" name="order_type" value="外卖" onclick="toggleOrderType()"> 外卖</label>
                        </div>
                    </div>

                    <div class="form-group" id="table_id_div">
                        <label for="table_id">选择餐桌</label>
                        <select name="table_id" id="table_id">
                            <option value="">请选择餐桌</option>
                            <?php foreach ($tables as $table): ?>
                                <option value="<?= $table['table_id']; ?>">餐桌 <?= $table['table_id']; ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group" id="address_div" style="display:none;">
                        <label for="address">配送地址</label>
                        <input type="text" name="address" id="address" placeholder="请输入详细配送地址">
                    </div>

                    <div class="form-group">
                        <label for="member_id">会员信息（可选）</label>
                        <select name="member_id" id="member_id">
                            <option value="">非会员</option>
                            <?php foreach ($members as $member): ?>
                                <option value="<?= $member['member_id']; ?>">会员ID: <?= $member['member_id']; ?> (<?= htmlspecialchars($member['phone']); ?>) - 等级<?= $member['level']; ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="remark">备注</label>
                        <textarea name="remark" id="remark" rows="2" placeholder="请输入特殊要求或备注信息"></textarea>
                    </div>

                    <div class="dish-search">
                        <input type="text" id="dish_search" placeholder="搜索菜品..." oninput="searchDishes()">
                    </div>

                    <div class="form-group">
                        <label>选择菜品</label>
                        <div class="menu-grid">
                            <?php foreach ($dishes as $dish): ?>
                                <div class="dish-card">
                                    <p><strong><?= htmlspecialchars($dish['name']); ?></strong></p>
                                    <p>￥<?= number_format($dish['price'], 2); ?> / 份</p>
                                    <p>库存: <?= $dish['stock']; ?> 份</p>
                                    <input type="number" name="items[<?= $dish['dish_id']; ?>]" data-price="<?= $dish['price']; ?>" min="0" max="<?= $dish['stock']; ?>" value="0" onchange="calculateTotal()">
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>

                <div class="right-column">
                    <div class="order-summary">
                        <h3>订单摘要</h3>
                        <p>总金额: ￥<span id="total_amount">0.00</span></p>

                        <div class="form-group">
                            <label for="payment_method">选择支付方式</label>
                            <select name="payment_method" id="payment_method" required>
                                <option value="">请选择</option>
                                <option value="现金">现金</option>
                                <option value="支付宝">支付宝</option>
                                <option value="微信">微信</option>
                                <option value="会员卡">会员卡</option>
                                <option value="银行卡">银行卡</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <button type="submit">创建订单</button>
                        </div>
                    </div>
                </div>
            </div>
        </form>
    </div>
</body>

</html>