<?php
require '../config.php';

// 获取桌号列表
$stmt = $pdo->query("SELECT table_id, qr_code FROM dining_tables ORDER BY table_id");
$tables = $stmt->fetchAll();

// 获取菜品列表（库存大于 0）
$stmt = $pdo->query("SELECT dish_id, name, price, stock FROM dishes WHERE stock > 0 ORDER BY name");
$dishes = $stmt->fetchAll();

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $table_id = $_POST['table_id'];
    $items = $_POST['items']; // 多个菜品

    if (!$table_id || empty($items)) {
        echo "<script>alert('请选择桌号并至少点一道菜');</script>";
    } else {
        try {
            $pdo->beginTransaction();

            // 生成唯一订单ID
            $order_id = date('YmdHis') . rand(1000, 9999);

            // 创建订单
            $stmt = $pdo->prepare("INSERT INTO orders (order_id, table_id, status, create_time) VALUES (?, ?, '待支付', NOW())");
            $stmt->execute([$order_id, $table_id]);

            // 订单详情
            foreach ($items as $dish_id => $qty) {
                if ($qty > 0) {
                    // 获取菜品价格
                    $stmt = $pdo->prepare("SELECT price FROM dishes WHERE dish_id = ?");
                    $stmt->execute([$dish_id]);
                    $dish = $stmt->fetch();

                    $stmt = $pdo->prepare("INSERT INTO order_details (order_id, dish_id, quantity, price, status) VALUES (?, ?, ?, ?, '等待中')");
                    $stmt->execute([$order_id, $dish_id, $qty, $dish['price']]);

                    // 更新库存
                    $stmt = $pdo->prepare("UPDATE dishes SET stock = stock - ? WHERE dish_id = ?");
                    $stmt->execute([$qty, $dish_id]);
                }
            }

            $pdo->commit();
            log_action('订单', '创建订单', "桌号ID: $table_id, 订单ID: $order_id");
            $message = "<div class='alert alert-success'>订单提交成功！3 秒后返回...</div>";
            header("refresh:6;url=" . $_SERVER['PHP_SELF']);
        } catch (Exception $e) {
            $pdo->rollBack();
            $message = "<div class='alert alert-danger'>提交失败: " . htmlspecialchars($e->getMessage()) . "</div>";
            header("refresh:6;url=" . $_SERVER['PHP_SELF']);
        }
    }
}
?>
<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <title>扫码点餐</title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h2>扫码点餐</h2>
        <form method="post">
            <?= csrf_field(); ?>
            <div class="form-group">
                <label for="table_id">选择桌号</label>
                <select name="table_id" id="table_id" required>
                    <option value="">请选择</option>
                    <?php foreach ($tables as $table): ?>
                        <option value="<?= $table['table_id']; ?>">
                            <?= "桌号 " . htmlspecialchars($table['table_id']) . "--二维码" . "（" . htmlspecialchars($table['qr_code']) . "）"; ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>

            <div class="form-group">
                <label>选择菜品</label>
                <div class="menu-grid">
                    <?php foreach ($dishes as $dish): ?>
                        <div class="dish-card">
                            <p><strong><?= htmlspecialchars($dish['name']); ?></strong></p>
                            <p>￥<?= number_format($dish['price'], 2); ?> / 份</p>
                            <p>库存: <?= $dish['stock']; ?> 份</p>
                            <input type="number" name="items[<?= $dish['dish_id']; ?>]" min="0" max="<?= $dish['stock']; ?>" value="0">
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>

            <div class="form-group">
                <button type="submit">提交订单</button>
            </div>
        </form>
    </div>
</body>

</html>