<?php
require_once '../config.php';


$message = '';
$order = null;
$order_details = [];
$available_dishes = [];

// 处理订单搜索
if (isset($_GET['search_order_id'])) {
    $search_order_id = $_GET['search_order_id'];

    // 获取订单信息
    $stmt = $pdo->prepare("SELECT * FROM orders WHERE order_id = ?");
    $stmt->execute([$search_order_id]);
    $order = $stmt->fetch();

    if ($order) {
        // 获取订单详情
        $stmt = $pdo->prepare("SELECT od.*, d.name, d.category, d.stock 
                              FROM order_details od 
                              JOIN dishes d ON od.dish_id = d.dish_id 
                              WHERE od.order_id = ?");
        $stmt->execute([$search_order_id]);
        $order_details = $stmt->fetchAll();

        // 获取可用菜品（库存大于0）
        $stmt = $pdo->query("SELECT dish_id, name, price, stock, category FROM dishes WHERE stock > 0 ORDER BY category, name");
        $available_dishes = $stmt->fetchAll();
    } else {
        $message = "<div class='error'>未找到订单号为 " . htmlspecialchars($search_order_id) . " 的订单</div>";
    }
}

// 处理订单修改
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $action = $_POST['action'] ?? '';
    $order_id = $_POST['order_id'] ?? '';

    try {
        $pdo->beginTransaction();

        if ($action === 'update_order') {
            // 获取当前订单状态
            $stmt = $pdo->prepare("SELECT status FROM orders WHERE order_id = ?");
            $stmt->execute([$order_id]);
            $current_status = $stmt->fetchColumn();

            // 只有待支付的订单才能完全修改
            if ($current_status === '待支付') {
                // 更新订单详情
                foreach ($_POST['items'] as $dish_id => $qty) {
                    $qty = (int)$qty;

                    // 检查是否已存在该菜品
                    $stmt = $pdo->prepare("SELECT quantity FROM order_details WHERE order_id = ? AND dish_id = ?");
                    $stmt->execute([$order_id, $dish_id]);
                    $existing_qty = $stmt->fetchColumn();

                    if ($existing_qty !== false) {
                        if ($qty > 0) {
                            // 更新数量
                            $stmt = $pdo->prepare("UPDATE order_details SET quantity = ? WHERE order_id = ? AND dish_id = ?");
                            $stmt->execute([$qty, $order_id, $dish_id]);

                            // 更新库存（考虑数量变化）
                            $qty_diff = $qty - $existing_qty;
                            if ($qty_diff != 0) {
                                $stmt = $pdo->prepare("UPDATE dishes SET stock = stock - ? WHERE dish_id = ?");
                                $stmt->execute([$qty_diff, $dish_id]);
                            }
                        } else {
                            // 删除菜品
                            $stmt = $pdo->prepare("DELETE FROM order_details WHERE order_id = ? AND dish_id = ?");
                            $stmt->execute([$order_id, $dish_id]);

                            // 恢复库存
                            $stmt = $pdo->prepare("UPDATE dishes SET stock = stock + ? WHERE dish_id = ?");
                            $stmt->execute([$existing_qty, $dish_id]);
                        }
                    } else if ($qty > 0) {
                        // 添加新菜品
                        $stmt = $pdo->prepare("SELECT price FROM dishes WHERE dish_id = ?");
                        $stmt->execute([$dish_id]);
                        $price = $stmt->fetchColumn();

                        $stmt = $pdo->prepare("INSERT INTO order_details (order_id, dish_id, quantity, price, status) VALUES (?, ?, ?, ?, '等待中')");
                        $stmt->execute([$order_id, $dish_id, $qty, $price]);

                        // 更新库存
                        $stmt = $pdo->prepare("UPDATE dishes SET stock = stock - ? WHERE dish_id = ?");
                        $stmt->execute([$qty, $dish_id]);
                    }
                }

                // 重新计算订单总金额
                $stmt = $pdo->prepare("SELECT SUM(quantity * price) FROM order_details WHERE order_id = ?");
                $stmt->execute([$order_id]);
                $total_amount = $stmt->fetchColumn() ?: 0;

                // 更新订单总金额
                $stmt = $pdo->prepare("UPDATE orders SET total_amount = ? WHERE order_id = ?");
                $stmt->execute([$total_amount, $order_id]);

                $message = "<div class='alert'>订单已成功更新</div>";
            } else if (in_array($current_status, ['进行中', '已完成'])) {
                // 已支付订单只能加菜
                $added_items = false;

                foreach ($_POST['items'] as $dish_id => $qty) {
                    $qty = (int)$qty;
                    if ($qty <= 0) continue;

                    // 检查是否已存在该菜品
                    $stmt = $pdo->prepare("SELECT quantity FROM order_details WHERE order_id = ? AND dish_id = ?");
                    $stmt->execute([$order_id, $dish_id]);
                    $existing_qty = $stmt->fetchColumn();

                    if ($existing_qty !== false) {
                        // 更新数量
                        $stmt = $pdo->prepare("UPDATE order_details SET quantity = quantity + ? WHERE order_id = ? AND dish_id = ?");
                        $stmt->execute([$qty, $order_id, $dish_id]);
                    } else {
                        // 添加新菜品
                        $stmt = $pdo->prepare("SELECT price FROM dishes WHERE dish_id = ?");
                        $stmt->execute([$dish_id]);
                        $price = $stmt->fetchColumn();

                        $stmt = $pdo->prepare("INSERT INTO order_details (order_id, dish_id, quantity, price, status) VALUES (?, ?, ?, ?, '等待中')");
                        $stmt->execute([$order_id, $dish_id, $qty, $price]);
                    }

                    // 更新库存
                    $stmt = $pdo->prepare("UPDATE dishes SET stock = stock - ? WHERE dish_id = ?");
                    $stmt->execute([$qty, $dish_id]);

                    $added_items = true;
                }

                if ($added_items) {
                    // 重新计算订单总金额
                    $stmt = $pdo->prepare("SELECT SUM(quantity * price) FROM order_details WHERE order_id = ?");
                    $stmt->execute([$order_id]);
                    $total_amount = $stmt->fetchColumn() ?: 0;

                    // 更新订单总金额
                    $stmt = $pdo->prepare("UPDATE orders SET total_amount = ? WHERE order_id = ?");
                    $stmt->execute([$total_amount, $order_id]);

                    // 同步到厨房订单
                    $stmt = $pdo->prepare("UPDATE kitchen_orders SET status = '待处理' WHERE order_id = ?");
                    $stmt->execute([$order_id]);

                    $message = "<div class='alert'>已成功为订单加菜</div>";
                } else {
                    $message = "<div class='error'>未添加任何菜品</div>";
                }
            }
        } else if ($action === 'cancel_order') {
            // 获取当前订单状态
            $stmt = $pdo->prepare("SELECT status, type, table_id FROM orders WHERE order_id = ?");
            $stmt->execute([$order_id]);
            $order_info = $stmt->fetch();

            if ($order_info) {
                // 只有待支付或进行中的订单才能取消
                if (in_array($order_info['status'], ['待支付', '进行中'])) {
                    // 恢复库存
                    $stmt = $pdo->prepare("SELECT dish_id, quantity FROM order_details WHERE order_id = ?");
                    $stmt->execute([$order_id]);
                    $items = $stmt->fetchAll();

                    foreach ($items as $item) {
                        $stmt = $pdo->prepare("UPDATE dishes SET stock = stock + ? WHERE dish_id = ?");
                        $stmt->execute([$item['quantity'], $item['dish_id']]);
                    }

                    // 如果是堂食订单，释放餐桌
                    if ($order_info['type'] === '堂食' && $order_info['table_id']) {
                        $stmt = $pdo->prepare("UPDATE dining_tables SET status = '空闲' WHERE table_id = ?");
                        $stmt->execute([$order_info['table_id']]);
                    }

                    // 更新订单状态
                    $stmt = $pdo->prepare("UPDATE orders SET status = '已取消' WHERE order_id = ?");
                    $stmt->execute([$order_id]);

                    // 更新厨房订单状态
                    $stmt = $pdo->prepare("UPDATE kitchen_orders SET status = '已取消' WHERE order_id = ?");
                    $stmt->execute([$order_id]);

                    $message = "<div class='alert'>订单已成功取消</div>";
                } else {
                    $message = "<div class='error'>只有待支付或进行中的订单才能取消</div>";
                }
            } else {
                $message = "<div class='error'>未找到订单</div>";
            }
        }

        $pdo->commit();

        // 重新获取订单信息
        if ($order_id) {
            $stmt = $pdo->prepare("SELECT * FROM orders WHERE order_id = ?");
            $stmt->execute([$order_id]);
            $order = $stmt->fetch();

            if ($order) {
                $stmt = $pdo->prepare("SELECT od.*, d.name, d.category, d.stock 
                                      FROM order_details od 
                                      JOIN dishes d ON od.dish_id = d.dish_id 
                                      WHERE od.order_id = ?");
                $stmt->execute([$order_id]);
                $order_details = $stmt->fetchAll();

                $stmt = $pdo->query("SELECT dish_id, name, price, stock, category FROM dishes WHERE stock > 0 ORDER BY category, name");
                $available_dishes = $stmt->fetchAll();
            }
        }
    } catch (Exception $e) {
        $pdo->rollBack();
        $message = "<div class='error'>操作失败: " . htmlspecialchars($e->getMessage()) . "</div>";
    }
}

// 获取最近的订单列表
$stmt = $pdo->query("SELECT order_id, type, status, total_amount, create_time FROM orders ORDER BY create_time DESC LIMIT 10");
$recent_orders = $stmt->fetchAll();
?>

<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <title>订单修改</title>
    <link rel="stylesheet" href="style.css">
    <style>
        .search-form {
            display: flex;
            gap: 10px;
            margin-bottom: 20px;
        }

        .search-form input {
            flex: 1;
            padding: 8px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }

        .search-form button {
            padding: 8px 15px;
            background-color: #3498db;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
        }

        .order-info {
            background-color: #f9f9f9;
            padding: 15px;
            border-radius: 8px;
            margin-bottom: 20px;
        }

        .order-info p {
            margin: 5px 0;
        }

        .dish-list {
            margin-bottom: 20px;
        }

        .dish-item {
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding: 10px;
            border-bottom: 1px solid #eee;
        }

        .dish-item:last-child {
            border-bottom: none;
        }

        .dish-actions {
            display: flex;
            gap: 10px;
        }

        .category-section {
            margin-bottom: 20px;
            border: 1px solid #ddd;
            border-radius: 8px;
            overflow: hidden;
        }

        .category-title {
            background-color: #f5f5f5;
            padding: 10px;
            font-weight: bold;
            border-bottom: 1px solid #ddd;
        }

        .category-dishes {
            padding: 10px;
        }

        .dish-select {
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding: 8px 0;
            border-bottom: 1px dashed #eee;
        }

        .dish-select:last-child {
            border-bottom: none;
        }

        .quantity-input {
            width: 60px;
            padding: 5px;
            text-align: center;
        }

        .action-buttons {
            display: flex;
            gap: 10px;
            margin-top: 20px;
        }

        .btn-primary {
            background-color: #3498db;
            color: white;
            border: none;
            padding: 10px 15px;
            border-radius: 4px;
            cursor: pointer;
        }

        .btn-danger {
            background-color: #e74c3c;
            color: white;
            border: none;
            padding: 10px 15px;
            border-radius: 4px;
            cursor: pointer;
        }

        .recent-orders {
            margin-top: 30px;
        }

        .recent-orders h3 {
            margin-bottom: 10px;
            border-bottom: 1px solid #ddd;
            padding-bottom: 5px;
        }

        .tabs {
            display: flex;
            border-bottom: 1px solid #ddd;
            margin-bottom: 20px;
        }

        .tab {
            padding: 10px 20px;
            cursor: pointer;
            border: 1px solid transparent;
        }

        .tab.active {
            border: 1px solid #ddd;
            border-bottom-color: #fff;
            border-radius: 4px 4px 0 0;
            margin-bottom: -1px;
            background-color: #fff;
        }

        .tab-content {
            display: none;
        }

        .tab-content.active {
            display: block;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>订单修改</h2>

        <?php if (isset($message)) echo $message; ?>

        <div class="search-form">
            <form method="get" action="">
                <input type="text" name="search_order_id" placeholder="输入订单号" required>
                <button type="submit">搜索订单</button>
            </form>
        </div>

        <?php if ($order): ?>
            <div class="order-info">
                <h3>订单信息</h3>
                <p><strong>订单号:</strong> <?= htmlspecialchars($order['order_id']); ?></p>
                <p><strong>订单类型:</strong> <?= htmlspecialchars($order['type']); ?></p>
                <p><strong>订单状态:</strong> <span class="status-tag <?= htmlspecialchars($order['status']); ?>"><?= htmlspecialchars($order['status']); ?></span></p>
                <p><strong>创建时间:</strong> <?= htmlspecialchars($order['create_time']); ?></p>
                <p><strong>总金额:</strong> ¥<?= htmlspecialchars(number_format($order['total_amount'], 2)); ?></p>
                <?php if ($order['table_id']): ?>
                    <p><strong>餐桌号:</strong> <?= htmlspecialchars($order['table_id']); ?></p>
                <?php endif; ?>
            </div>

            <div class="tabs">
                <div class="tab active" onclick="switchTab('current-items')">当前菜品</div>
                <div class="tab" onclick="switchTab('add-items')">添加菜品</div>
            </div>

            <form method="post" action="">
                <input type="hidden" name="action" value="update_order">
                <input type="hidden" name="order_id" value="<?= htmlspecialchars($order['order_id']); ?>">

                <div id="current-items" class="tab-content active">
                    <h3>当前菜品</h3>
                    <?php if (empty($order_details)): ?>
                        <p>订单中没有菜品</p>
                    <?php else: ?>
                        <div class="dish-list">
                            <?php
                            // 按类别分组显示菜品
                            $grouped_dishes = [];
                            foreach ($order_details as $dish) {
                                $grouped_dishes[$dish['category']][] = $dish;
                            }

                            foreach ($grouped_dishes as $category => $category_dishes):
                            ?>
                                <div class="category-section">
                                    <div class="category-title"><?= htmlspecialchars($category); ?></div>
                                    <div class="category-dishes">
                                        <?php foreach ($category_dishes as $dish): ?>
                                            <div class="dish-item">
                                                <div>
                                                    <span><?= htmlspecialchars($dish['name']); ?></span>
                                                    <span>(¥<?= htmlspecialchars(number_format($dish['price'], 2)); ?>/份)</span>
                                                </div>
                                                <div class="dish-actions">
                                                    <span class="status-tag <?= htmlspecialchars($dish['status']); ?>"><?= htmlspecialchars($dish['status']); ?></span>
                                                    <?php if ($order['status'] === '待支付'): ?>
                                                        <input type="number" name="items[<?= $dish['dish_id']; ?>]" value="<?= htmlspecialchars($dish['quantity']); ?>" min="0" max="<?= $dish['stock'] + $dish['quantity']; ?>" class="quantity-input">
                                                    <?php else: ?>
                                                        <span>数量: <?= htmlspecialchars($dish['quantity']); ?></span>
                                                    <?php endif; ?>
                                                </div>
                                            </div>
                                        <?php endforeach; ?>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    <?php endif; ?>
                </div>

                <div id="add-items" class="tab-content">
                    <h3>添加菜品</h3>
                    <?php if (empty($available_dishes)): ?>
                        <p>没有可用的菜品</p>
                    <?php else: ?>
                        <?php
                        // 按类别分组显示可用菜品
                        $grouped_available = [];
                        foreach ($available_dishes as $dish) {
                            $grouped_available[$dish['category']][] = $dish;
                        }

                        foreach ($grouped_available as $category => $category_dishes):
                        ?>
                            <div class="category-section">
                                <div class="category-title"><?= htmlspecialchars($category); ?></div>
                                <div class="category-dishes">
                                    <?php foreach ($category_dishes as $dish): ?>
                                        <div class="dish-select">
                                            <div>
                                                <span><?= htmlspecialchars($dish['name']); ?></span>
                                                <span>(¥<?= htmlspecialchars(number_format($dish['price'], 2)); ?>/份)</span>
                                                <span>库存: <?= htmlspecialchars($dish['stock']); ?></span>
                                            </div>
                                            <div>
                                                <?php
                                                // 检查是否已在订单中
                                                $existing_qty = 0;
                                                foreach ($order_details as $od) {
                                                    if ($od['dish_id'] == $dish['dish_id']) {
                                                        $existing_qty = $od['quantity'];
                                                        break;
                                                    }
                                                }
                                                ?>
                                                <?php if ($order['status'] === '待支付'): ?>
                                                    <input type="number" name="items[<?= $dish['dish_id']; ?>]" value="<?= $existing_qty; ?>" min="0" max="<?= $dish['stock'] + $existing_qty; ?>" class="quantity-input">
                                                <?php else: ?>
                                                    <input type="number" name="items[<?= $dish['dish_id']; ?>]" value="0" min="0" max="<?= $dish['stock']; ?>" class="quantity-input">
                                                <?php endif; ?>
                                            </div>
                                        </div>
                                    <?php endforeach; ?>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    <?php endif; ?>
                </div>

                <div class="action-buttons">
                    <?php if ($order['status'] === '待支付'): ?>
                        <button type="submit" class="btn-primary">更新订单</button>
                    <?php elseif (in_array($order['status'], ['进行中', '已完成'])): ?>
                        <button type="submit" class="btn-primary">加菜</button>
                    <?php endif; ?>

                    <?php if (in_array($order['status'], ['待支付', '进行中'])): ?>
                        <button type="button" class="btn-danger" onclick="confirmCancel('<?= htmlspecialchars($order['order_id']); ?>')">取消订单</button>
                    <?php endif; ?>
                </div>
            </form>
        <?php endif; ?>

        <div class="recent-orders">
            <h3>最近订单</h3>
            <?php if (empty($recent_orders)): ?>
                <p>没有最近的订单</p>
            <?php else: ?>
                <table>
                    <thead>
                        <tr>
                            <th>订单号</th>
                            <th>类型</th>
                            <th>状态</th>
                            <th>金额</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($recent_orders as $recent): ?>
                            <tr>
                                <td><?= htmlspecialchars($recent['order_id']); ?></td>
                                <td><?= htmlspecialchars($recent['type']); ?></td>
                                <td><span class="status-tag <?= htmlspecialchars($recent['status']); ?>"><?= htmlspecialchars($recent['status']); ?></span></td>
                                <td>¥<?= htmlspecialchars(number_format($recent['total_amount'], 2)); ?></td>
                                <td><?= htmlspecialchars($recent['create_time']); ?></td>
                                <td>
                                    <a href="?search_order_id=<?= htmlspecialchars($recent['order_id']); ?>" class="btn-link">查看</a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            <?php endif; ?>
        </div>
    </div>

    <form id="cancel-form" method="post" style="display: none;">
        <input type="hidden" name="action" value="cancel_order">
        <input type="hidden" name="order_id" id="cancel-order-id">
    </form>

    <script>
        function switchTab(tabId) {
            // 隐藏所有标签内容
            document.querySelectorAll('.tab-content').forEach(function(content) {
                content.classList.remove('active');
            });

            // 取消所有标签的活动状态
            document.querySelectorAll('.tab').forEach(function(tab) {
                tab.classList.remove('active');
            });

            // 显示选中的标签内容
            document.getElementById(tabId).classList.add('active');

            // 设置选中标签的活动状态
            document.querySelector('.tab[onclick="switchTab(\'' + tabId + '\')"]').classList.add('active');
        }

        function confirmCancel(orderId) {
            if (confirm('确定要取消此订单吗？此操作不可撤销。')) {
                document.getElementById('cancel-order-id').value = orderId;
                document.getElementById('cancel-form').submit();
            }
        }
    </script>
</body>

</html>