<?php
require_once '../config.php';


$message = '';
$orders = [];
$total_amount = 0;
$total_count = 0;

// 设置默认查询参数
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-7 days'));
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');
$status = isset($_GET['status']) ? $_GET['status'] : '';
$type = isset($_GET['type']) ? $_GET['type'] : '';
$order_id = isset($_GET['order_id']) ? $_GET['order_id'] : '';
$table_id = isset($_GET['table_id']) ? $_GET['table_id'] : '';
$payment_method = isset($_GET['payment_method']) ? $_GET['payment_method'] : '';

// 构建查询
$query = "SELECT o.*, 
          (SELECT COUNT(*) FROM order_details WHERE order_id = o.order_id) as dish_count,
          p.method as payment_method
          FROM orders o 
          LEFT JOIN payments p ON o.order_id = p.order_id
          WHERE 1=1";
$params = [];

// 添加筛选条件
if ($start_date) {
    $query .= " AND DATE(o.create_time) >= ?";
    $params[] = $start_date;
}

if ($end_date) {
    $query .= " AND DATE(o.create_time) <= ?";
    $params[] = $end_date;
}

if ($status) {
    $query .= " AND o.status = ?";
    $params[] = $status;
}

if ($type) {
    $query .= " AND o.type = ?";
    $params[] = $type;
}

if ($order_id) {
    $query .= " AND o.order_id LIKE ?";
    $params[] = "%$order_id%";
}

if ($table_id) {
    $query .= " AND o.table_id = ?";
    $params[] = $table_id;
}

if ($payment_method) {
    $query .= " AND p.method = ?";
    $params[] = $payment_method;
}

// 添加排序
$query .= " ORDER BY o.create_time DESC";

// 执行查询
try {
    $stmt = $pdo->prepare($query);
    $stmt->execute($params);
    $orders = $stmt->fetchAll();

    // 计算总金额和订单数量
    $total_count = count($orders);
    foreach ($orders as $order) {
        if ($order['status'] !== '已取消') {
            $total_amount += $order['total_amount'];
        }
    }
} catch (Exception $e) {
    $message = "<div class='error'>查询失败: " . htmlspecialchars($e->getMessage()) . "</div>";
}

// 获取订单状态列表
$stmt = $pdo->query("SELECT DISTINCT status FROM orders ORDER BY status");
$statuses = $stmt->fetchAll(PDO::FETCH_COLUMN);

// 获取订单类型列表
$stmt = $pdo->query("SELECT DISTINCT type FROM orders ORDER BY type");
$types = $stmt->fetchAll(PDO::FETCH_COLUMN);

// 获取餐桌列表
$stmt = $pdo->query("SELECT table_id FROM dining_tables ORDER BY table_id");
$tables = $stmt->fetchAll(PDO::FETCH_COLUMN);

// 获取支付方式列表
$stmt = $pdo->query("SELECT DISTINCT method FROM payments ORDER BY method");
$payment_methods = $stmt->fetchAll(PDO::FETCH_COLUMN);

// 处理导出CSV
if (isset($_GET['export']) && $_GET['export'] === 'csv') {
    header('Content-Type: text/csv; charset=utf-8');
    header('Content-Disposition: attachment; filename="订单历史_' . date('Y-m-d') . '.csv"');

    $output = fopen('php://output', 'w');

    // 添加BOM以支持中文
    fprintf($output, chr(0xEF) . chr(0xBB) . chr(0xBF));

    // 写入CSV头
    fputcsv($output, ['订单号', '用户ID', '餐桌号', '类型', '状态', '总金额', '创建时间', '支付时间', '支付方式', '菜品数量']);

    // 写入数据
    foreach ($orders as $order) {
        fputcsv($output, [
            $order['order_id'],
            $order['user_id'] ?: '',
            $order['table_id'] ?: '',
            $order['type'],
            $order['status'],
            $order['total_amount'],
            $order['create_time'],
            $order['payment_time'] ?: '',
            $order['payment_method'] ?: '',
            $order['dish_count']
        ]);
    }

    fclose($output);
    exit;
}

// 处理查看订单详情
$order_details = [];
if (isset($_GET['view_details']) && !empty($_GET['view_details'])) {
    $detail_order_id = $_GET['view_details'];

    // 获取订单详情
    $stmt = $pdo->prepare("SELECT od.*, d.name, d.category 
                          FROM order_details od 
                          JOIN dishes d ON od.dish_id = d.dish_id 
                          WHERE od.order_id = ?
                          ORDER BY d.category, d.name");
    $stmt->execute([$detail_order_id]);
    $order_details = $stmt->fetchAll();

    // 获取订单信息
    $stmt = $pdo->prepare("SELECT o.*, p.method as payment_method, p.payment_id
                          FROM orders o 
                          LEFT JOIN payments p ON o.order_id = p.order_id
                          WHERE o.order_id = ?");
    $stmt->execute([$detail_order_id]);
    $order_info = $stmt->fetch();
}
?>

<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <title>订单历史查询</title>
    <link rel="stylesheet" href="style.css">
    <style>
        .filter-form {
            background-color: #f9f9f9;
            padding: 15px;
            border-radius: 8px;
            margin-bottom: 20px;
        }

        .filter-row {
            display: flex;
            flex-wrap: wrap;
            gap: 15px;
            margin-bottom: 15px;
        }

        .filter-item {
            flex: 1;
            min-width: 200px;
        }

        .filter-item label {
            display: block;
            margin-bottom: 5px;
            font-weight: bold;
        }

        .filter-item input,
        .filter-item select {
            width: 100%;
            padding: 8px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }

        .filter-buttons {
            display: flex;
            gap: 10px;
            justify-content: flex-end;
        }

        .btn-primary {
            background-color: #3498db;
            color: white;
            border: none;
            padding: 8px 15px;
            border-radius: 4px;
            cursor: pointer;
        }

        .btn-secondary {
            background-color: #95a5a6;
            color: white;
            border: none;
            padding: 8px 15px;
            border-radius: 4px;
            cursor: pointer;
        }

        .summary-box {
            background-color: #f9f9f9;
            padding: 15px;
            border-radius: 8px;
            margin-bottom: 20px;
            display: flex;
            justify-content: space-between;
        }

        .summary-item {
            text-align: center;
        }

        .summary-value {
            font-size: 24px;
            font-weight: bold;
            color: #3498db;
        }

        .summary-label {
            font-size: 14px;
            color: #7f8c8d;
        }

        .order-table {
            width: 100%;
            border-collapse: collapse;
            margin-bottom: 20px;
        }

        .order-table th,
        .order-table td {
            padding: 10px;
            border: 1px solid #ddd;
            text-align: left;
        }

        .order-table th {
            background-color: #f5f5f5;
            font-weight: bold;
        }

        .order-table tr:nth-child(even) {
            background-color: #f9f9f9;
        }

        .order-table tr:hover {
            background-color: #f1f1f1;
        }

        .pagination {
            display: flex;
            justify-content: center;
            margin-top: 20px;
        }

        .pagination a {
            padding: 8px 12px;
            margin: 0 5px;
            border: 1px solid #ddd;
            text-decoration: none;
            color: #3498db;
            border-radius: 4px;
        }

        .pagination a.active {
            background-color: #3498db;
            color: white;
            border-color: #3498db;
        }

        .modal {
            display: none;
            position: fixed;
            z-index: 1000;
            left: 0;
            top: 0;
            width: 100%;
            height: 100%;
            background-color: rgba(0, 0, 0, 0.5);
        }

        .modal-content {
            background-color: #fff;
            margin: 5% auto;
            padding: 20px;
            border-radius: 8px;
            width: 80%;
            max-width: 800px;
            max-height: 80vh;
            overflow-y: auto;
        }

        .close {
            color: #aaa;
            float: right;
            font-size: 28px;
            font-weight: bold;
            cursor: pointer;
        }

        .close:hover {
            color: #000;
        }

        .detail-header {
            margin-bottom: 20px;
            padding-bottom: 10px;
            border-bottom: 1px solid #ddd;
        }

        .detail-info {
            display: flex;
            flex-wrap: wrap;
            gap: 20px;
            margin-bottom: 20px;
        }

        .detail-info-item {
            flex: 1;
            min-width: 200px;
        }

        .detail-items {
            margin-top: 20px;
        }

        .category-section {
            margin-bottom: 20px;
        }

        .category-title {
            font-size: 16px;
            font-weight: bold;
            margin-bottom: 10px;
            padding-bottom: 5px;
            border-bottom: 1px solid #ddd;
        }

        .detail-item {
            display: flex;
            justify-content: space-between;
            padding: 8px 0;
            border-bottom: 1px dashed #eee;
        }

        .detail-item:last-child {
            border-bottom: none;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>订单历史查询</h2>

        <?php if (isset($message)) echo $message; ?>

        <form method="get" class="filter-form">
            <div class="filter-row">
                <div class="filter-item">
                    <label for="start_date">开始日期</label>
                    <input type="date" id="start_date" name="start_date" value="<?= htmlspecialchars($start_date); ?>">
                </div>
                <div class="filter-item">
                    <label for="end_date">结束日期</label>
                    <input type="date" id="end_date" name="end_date" value="<?= htmlspecialchars($end_date); ?>">
                </div>
                <div class="filter-item">
                    <label for="status">订单状态</label>
                    <select id="status" name="status">
                        <option value="">全部</option>
                        <?php foreach ($statuses as $s): ?>
                            <option value="<?= htmlspecialchars($s); ?>" <?= $status === $s ? 'selected' : ''; ?>><?= htmlspecialchars($s); ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>
            </div>

            <div class="filter-row">
                <div class="filter-item">
                    <label for="type">订单类型</label>
                    <select id="type" name="type">
                        <option value="">全部</option>
                        <?php foreach ($types as $t): ?>
                            <option value="<?= htmlspecialchars($t); ?>" <?= $type === $t ? 'selected' : ''; ?>><?= htmlspecialchars($t); ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="filter-item">
                    <label for="order_id">订单号</label>
                    <input type="text" id="order_id" name="order_id" value="<?= htmlspecialchars($order_id); ?>" placeholder="输入订单号">
                </div>
                <div class="filter-item">
                    <label for="table_id">餐桌号</label>
                    <select id="table_id" name="table_id">
                        <option value="">全部</option>
                        <?php foreach ($tables as $t): ?>
                            <option value="<?= htmlspecialchars($t); ?>" <?= $table_id == $t ? 'selected' : ''; ?>><?= htmlspecialchars($t); ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>
            </div>

            <div class="filter-row">
                <div class="filter-item">
                    <label for="payment_method">支付方式</label>
                    <select id="payment_method" name="payment_method">
                        <option value="">全部</option>
                        <?php foreach ($payment_methods as $pm): ?>
                            <option value="<?= htmlspecialchars($pm); ?>" <?= $payment_method === $pm ? 'selected' : ''; ?>><?= htmlspecialchars($pm); ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="filter-item">
                    <!-- 空白占位 -->
                </div>
                <div class="filter-item">
                    <!-- 空白占位 -->
                </div>
            </div>

            <div class="filter-buttons">
                <button type="submit" class="btn-primary">查询</button>
                <button type="button" class="btn-secondary" onclick="resetForm()">重置</button>
                <button type="button" class="btn-secondary" onclick="exportCSV()">导出CSV</button>
            </div>
        </form>

        <div class="summary-box">
            <div class="summary-item">
                <div class="summary-value"><?= $total_count; ?></div>
                <div class="summary-label">订单总数</div>
            </div>
            <div class="summary-item">
                <div class="summary-value">¥<?= number_format($total_amount, 2); ?></div>
                <div class="summary-label">总金额（不含已取消）</div>
            </div>
            <div class="summary-item">
                <div class="summary-value"><?= $total_count > 0 ? number_format($total_amount / $total_count, 2) : '0.00'; ?></div>
                <div class="summary-label">平均订单金额</div>
            </div>
        </div>

        <?php if (empty($orders)): ?>
            <div class="empty-state">
                <p>没有找到符合条件的订单</p>
            </div>
        <?php else: ?>
            <table class="order-table">
                <thead>
                    <tr>
                        <th>订单号</th>
                        <th>类型</th>
                        <th>状态</th>
                        <th>金额</th>
                        <th>餐桌号</th>
                        <th>菜品数量</th>
                        <th>创建时间</th>
                        <th>支付方式</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($orders as $order): ?>
                        <tr>
                            <td><?= htmlspecialchars($order['order_id']); ?></td>
                            <td><?= htmlspecialchars($order['type']); ?></td>
                            <td><span class="status-tag <?= htmlspecialchars($order['status']); ?>"><?= htmlspecialchars($order['status']); ?></span></td>
                            <td>¥<?= htmlspecialchars(number_format($order['total_amount'], 2)); ?></td>
                            <td><?= $order['table_id'] ? htmlspecialchars($order['table_id']) : '-'; ?></td>
                            <td><?= htmlspecialchars($order['dish_count']); ?></td>
                            <td><?= htmlspecialchars($order['create_time']); ?></td>
                            <td><?= $order['payment_method'] ? htmlspecialchars($order['payment_method']) : '-'; ?></td>
                            <td>
                                <a href="?<?= http_build_query(array_merge($_GET, ['view_details' => $order['order_id']])); ?>" class="btn-link">查看详情</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        <?php endif; ?>
    </div>

    <?php if (!empty($order_details) && isset($order_info)): ?>
        <div id="orderDetailModal" class="modal" style="display: block;">
            <div class="modal-content">
                <span class="close" onclick="closeModal()">&times;</span>

                <div class="detail-header">
                    <h3>订单详情: <?= htmlspecialchars($order_info['order_id']); ?></h3>
                </div>

                <div class="detail-info">
                    <div class="detail-info-item">
                        <p><strong>订单类型:</strong> <?= htmlspecialchars($order_info['type']); ?></p>
                        <p><strong>订单状态:</strong> <span class="status-tag <?= htmlspecialchars($order_info['status']); ?>"><?= htmlspecialchars($order_info['status']); ?></span></p>
                        <p><strong>总金额:</strong> ¥<?= htmlspecialchars(number_format($order_info['total_amount'], 2)); ?></p>
                    </div>

                    <div class="detail-info-item">
                        <p><strong>创建时间:</strong> <?= htmlspecialchars($order_info['create_time']); ?></p>
                        <p><strong>支付时间:</strong> <?= $order_info['payment_time'] ? htmlspecialchars($order_info['payment_time']) : '-'; ?></p>
                        <p><strong>支付方式:</strong> <?= $order_info['payment_method'] ? htmlspecialchars($order_info['payment_method']) : '-'; ?></p>
                    </div>

                    <div class="detail-info-item">
                        <p><strong>用户ID:</strong> <?= $order_info['user_id'] ? htmlspecialchars($order_info['user_id']) : '-'; ?></p>
                        <p><strong>餐桌号:</strong> <?= $order_info['table_id'] ? htmlspecialchars($order_info['table_id']) : '-'; ?></p>
                        <p><strong>支付ID:</strong> <?= $order_info['payment_id'] ? htmlspecialchars($order_info['payment_id']) : '-'; ?></p>
                    </div>
                </div>

                <div class="detail-items">
                    <h4>订单菜品</h4>

                    <?php if (empty($order_details)): ?>
                        <p>没有菜品信息</p>
                    <?php else: ?>
                        <?php
                        // 按类别分组显示菜品
                        $grouped_items = [];
                        foreach ($order_details as $item) {
                            $grouped_items[$item['category']][] = $item;
                        }

                        foreach ($grouped_items as $category => $category_items):
                        ?>
                            <div class="category-section">
                                <div class="category-title"><?= htmlspecialchars($category); ?></div>
                                <?php foreach ($category_items as $item): ?>
                                    <div class="detail-item">
                                        <div>
                                            <span><?= htmlspecialchars($item['name']); ?> x <?= htmlspecialchars($item['quantity']); ?></span>
                                        </div>
                                        <div>
                                            <span>¥<?= htmlspecialchars(number_format($item['price'], 2)); ?> / 份</span>
                                            <span class="status-tag <?= htmlspecialchars($item['status']); ?>"><?= htmlspecialchars($item['status']); ?></span>
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            </div>
                        <?php endforeach; ?>

                        <div class="total-summary" style="text-align: right; margin-top: 20px;">
                            <strong>总计: ¥<?= htmlspecialchars(number_format($order_info['total_amount'], 2)); ?></strong>
                        </div>
                    <?php endif; ?>
                </div>

                <?php if ($order_info['remark']): ?>
                    <div style="margin-top: 20px;">
                        <h4>备注</h4>
                        <p><?= nl2br(htmlspecialchars($order_info['remark'])); ?></p>
                    </div>
                <?php endif; ?>
            </div>
        </div>
    <?php endif; ?>

    <script>
        function resetForm() {
            document.getElementById('start_date').value = '<?= date('Y-m-d', strtotime('-7 days')); ?>';
            document.getElementById('end_date').value = '<?= date('Y-m-d'); ?>';
            document.getElementById('status').value = '';
            document.getElementById('type').value = '';
            document.getElementById('order_id').value = '';
            document.getElementById('table_id').value = '';
            document.getElementById('payment_method').value = '';
        }

        function exportCSV() {
            // 获取当前的查询参数
            const currentUrl = new URL(window.location.href);
            const params = new URLSearchParams(currentUrl.search);

            // 添加导出参数
            params.set('export', 'csv');

            // 创建导出URL
            const exportUrl = `${currentUrl.pathname}?${params.toString()}`;

            // 打开新窗口下载
            window.open(exportUrl, '_blank');
        }

        function closeModal() {
            // 移除查询参数中的view_details
            const currentUrl = new URL(window.location.href);
            const params = new URLSearchParams(currentUrl.search);

            params.delete('view_details');

            // 重定向到没有view_details参数的URL
            window.location.href = `${currentUrl.pathname}?${params.toString()}`;
        }

        // 如果按下ESC键，关闭模态框
        document.addEventListener('keydown', function(event) {
            if (event.key === 'Escape') {
                const modal = document.getElementById('orderDetailModal');
                if (modal && modal.style.display === 'block') {
                    closeModal();
                }
            }
        });

        // 点击模态框外部关闭
        window.addEventListener('click', function(event) {
            const modal = document.getElementById('orderDetailModal');
            if (modal && event.target === modal) {
                closeModal();
            }
        });
    </script>
</body>

</html>