<?php
require_once '../config.php';


$message = '';
$orders = [];
$selected_orders = [];
$split_order = null;
$split_items = [];

// 获取所有待支付的订单
$stmt = $pdo->query("SELECT o.order_id, o.user_id, o.table_id, o.type, o.status, o.total_amount, o.create_time,
                     (SELECT COUNT(*) FROM order_details WHERE order_id = o.order_id) as dish_count
                     FROM orders o 
                     WHERE o.status = '待支付' 
                     ORDER BY o.create_time DESC");
$pending_orders = $stmt->fetchAll();

// 处理订单合并
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action'])) {
    if ($_POST['action'] === 'merge_orders') {
        $order_ids = $_POST['order_ids'] ?? [];

        if (count($order_ids) < 2) {
            $message = "<div class='error'>请至少选择两个订单进行合并</div>";
        } else {
            try {
                $pdo->beginTransaction();

                // 生成新的合并订单ID
                $merged_order_id = 'M' . date('YmdHis') . rand(100, 999);

                // 获取所有选中订单的信息
                $placeholders = str_repeat('?,', count($order_ids) - 1) . '?';
                $stmt = $pdo->prepare("SELECT * FROM orders WHERE order_id IN ($placeholders)");
                $stmt->execute($order_ids);
                $orders_to_merge = $stmt->fetchAll();

                // 计算总金额
                $total_amount = 0;
                foreach ($orders_to_merge as $order) {
                    $total_amount += $order['total_amount'];
                }

                // 创建合并订单
                $stmt = $pdo->prepare("INSERT INTO orders (order_id, user_id, type, status, total_amount, create_time, remark) 
                                      VALUES (?, NULL, '合并订单', '待支付', ?, NOW(), '合并订单: " . implode(',', $order_ids) . "')");
                $stmt->execute([$merged_order_id, $total_amount]);

                // 复制所有订单详情到新订单
                foreach ($order_ids as $order_id) {
                    $stmt = $pdo->prepare("INSERT INTO order_details (order_id, dish_id, quantity, price, status) 
                                          SELECT ?, dish_id, quantity, price, status 
                                          FROM order_details 
                                          WHERE order_id = ?");
                    $stmt->execute([$merged_order_id, $order_id]);

                    // 更新原订单状态为已合并
                    $stmt = $pdo->prepare("UPDATE orders SET status = '已取消', remark = CONCAT(IFNULL(remark, ''), ' (已合并到 $merged_order_id)') WHERE order_id = ?");
                    $stmt->execute([$order_id]);
                }

                // 同步到厨房订单
                $stmt = $pdo->prepare("INSERT INTO kitchen_orders (order_id, status, create_time) VALUES (?, '待处理', NOW())");
                $stmt->execute([$merged_order_id]);

                $pdo->commit();
                $message = "<div class='alert'>订单合并成功，新订单号: " . htmlspecialchars($merged_order_id) . "</div>";

                // 重新获取待支付订单
                $stmt = $pdo->query("SELECT o.order_id, o.user_id, o.table_id, o.type, o.status, o.total_amount, o.create_time,
                                    (SELECT COUNT(*) FROM order_details WHERE order_id = o.order_id) as dish_count
                                    FROM orders o 
                                    WHERE o.status = '待支付' 
                                    ORDER BY o.create_time DESC");
                $pending_orders = $stmt->fetchAll();
            } catch (Exception $e) {
                $pdo->rollBack();
                $message = "<div class='error'>合并失败: " . htmlspecialchars($e->getMessage()) . "</div>";
            }
        }
    } else if ($_POST['action'] === 'load_split_order') {
        $order_id = $_POST['order_id'] ?? '';

        if (!$order_id) {
            $message = "<div class='error'>请选择要拆分的订单</div>";
        } else {
            // 获取订单信息
            $stmt = $pdo->prepare("SELECT * FROM orders WHERE order_id = ?");
            $stmt->execute([$order_id]);
            $split_order = $stmt->fetch();

            if ($split_order) {
                // 获取订单详情
                $stmt = $pdo->prepare("SELECT od.*, d.name, d.category 
                                      FROM order_details od 
                                      JOIN dishes d ON od.dish_id = d.dish_id 
                                      WHERE od.order_id = ?");
                $stmt->execute([$order_id]);
                $split_items = $stmt->fetchAll();
            } else {
                $message = "<div class='error'>未找到订单</div>";
            }
        }
    } else if ($_POST['action'] === 'split_order') {
        $order_id = $_POST['order_id'] ?? '';
        $split_groups = $_POST['split_groups'] ?? [];

        if (!$order_id) {
            $message = "<div class='error'>请选择要拆分的订单</div>";
        } else if (empty($split_groups) || count(array_filter($split_groups)) < 2) {
            $message = "<div class='error'>请至少将菜品分配到两个不同的组</div>";
        } else {
            try {
                $pdo->beginTransaction();

                // 获取原订单信息
                $stmt = $pdo->prepare("SELECT * FROM orders WHERE order_id = ?");
                $stmt->execute([$order_id]);
                $original_order = $stmt->fetch();

                if (!$original_order) {
                    throw new Exception("未找到订单");
                }

                // 获取订单详情
                $stmt = $pdo->prepare("SELECT * FROM order_details WHERE order_id = ?");
                $stmt->execute([$order_id]);
                $original_items = $stmt->fetchAll();

                // 按组拆分订单
                $group_orders = [];
                $group_totals = [];

                // 初始化每个组的总金额
                foreach (array_unique(array_filter($split_groups)) as $group) {
                    $group_totals[$group] = 0;
                }

                // 计算每个组的总金额
                foreach ($original_items as $index => $item) {
                    $group = $split_groups[$index] ?? '';
                    if ($group) {
                        $group_totals[$group] += $item['quantity'] * $item['price'];
                    }
                }

                // 创建拆分订单
                foreach ($group_totals as $group => $total) {
                    // 生成新订单ID
                    $new_order_id = 'S' . $group . date('YmdHis') . rand(10, 99);

                    // 创建新订单
                    $stmt = $pdo->prepare("INSERT INTO orders (order_id, user_id, table_id, type, status, total_amount, create_time, remark) 
                                          VALUES (?, ?, ?, ?, '待支付', ?, NOW(), '拆分自订单: $order_id (组 $group)')");
                    $stmt->execute([
                        $new_order_id,
                        $original_order['user_id'],
                        $original_order['table_id'],
                        $original_order['type'],
                        $total
                    ]);

                    // 复制相应组的订单详情
                    foreach ($original_items as $index => $item) {
                        if (($split_groups[$index] ?? '') == $group) {
                            $stmt = $pdo->prepare("INSERT INTO order_details (order_id, dish_id, quantity, price, status) 
                                                  VALUES (?, ?, ?, ?, ?)");
                            $stmt->execute([
                                $new_order_id,
                                $item['dish_id'],
                                $item['quantity'],
                                $item['price'],
                                $item['status']
                            ]);
                        }
                    }

                    // 同步到厨房订单
                    $stmt = $pdo->prepare("INSERT INTO kitchen_orders (order_id, status, create_time) VALUES (?, '待处理', NOW())");
                    $stmt->execute([$new_order_id]);

                    $group_orders[] = $new_order_id;
                }

                // 更新原订单状态为已拆分
                $stmt = $pdo->prepare("UPDATE orders SET status = '已取消', remark = CONCAT(IFNULL(remark, ''), ' (已拆分为 " . implode(',', $group_orders) . ")') WHERE order_id = ?");
                $stmt->execute([$order_id]);

                // 更新厨房订单状态
                $stmt = $pdo->prepare("UPDATE kitchen_orders SET status = '已取消' WHERE order_id = ?");
                $stmt->execute([$order_id]);

                $pdo->commit();
                $message = "<div class='alert'>订单拆分成功，新订单号: " . htmlspecialchars(implode(', ', $group_orders)) . "</div>";

                // 重新获取待支付订单
                $stmt = $pdo->query("SELECT o.order_id, o.user_id, o.table_id, o.type, o.status, o.total_amount, o.create_time,
                                    (SELECT COUNT(*) FROM order_details WHERE order_id = o.order_id) as dish_count
                                    FROM orders o 
                                    WHERE o.status = '待支付' 
                                    ORDER BY o.create_time DESC");
                $pending_orders = $stmt->fetchAll();

                // 清空拆分订单信息
                $split_order = null;
                $split_items = [];
            } catch (Exception $e) {
                $pdo->rollBack();
                $message = "<div class='error'>拆分失败: " . htmlspecialchars($e->getMessage()) . "</div>";
            }
        }
    }
}
?>

<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <title>订单合并/拆单</title>
    <link rel="stylesheet" href="style.css">
    <style>
        .tabs {
            display: flex;
            border-bottom: 1px solid #ddd;
            margin-bottom: 20px;
        }

        .tab {
            padding: 10px 20px;
            cursor: pointer;
            border: 1px solid transparent;
        }

        .tab.active {
            border: 1px solid #ddd;
            border-bottom-color: #fff;
            border-radius: 4px 4px 0 0;
            margin-bottom: -1px;
            background-color: #fff;
        }

        .tab-content {
            display: none;
        }

        .tab-content.active {
            display: block;
        }

        .order-list {
            margin-bottom: 20px;
        }

        .order-card {
            border: 1px solid #ddd;
            border-radius: 8px;
            margin-bottom: 15px;
            padding: 15px;
            background-color: #fff;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }

        .order-info {
            flex: 1;
        }

        .order-actions {
            display: flex;
            gap: 10px;
            align-items: center;
        }

        .btn-primary {
            background-color: #3498db;
            color: white;
            border: none;
            padding: 8px 15px;
            border-radius: 4px;
            cursor: pointer;
        }

        .btn-secondary {
            background-color: #95a5a6;
            color: white;
            border: none;
            padding: 8px 15px;
            border-radius: 4px;
            cursor: pointer;
        }

        .selected-orders {
            margin-top: 20px;
            padding: 15px;
            background-color: #f9f9f9;
            border-radius: 8px;
        }

        .selected-orders h3 {
            margin-top: 0;
            margin-bottom: 10px;
        }

        .selected-order-item {
            display: flex;
            justify-content: space-between;
            padding: 8px 0;
            border-bottom: 1px dashed #ddd;
        }

        .selected-order-item:last-child {
            border-bottom: none;
        }

        .split-container {
            margin-top: 20px;
        }

        .split-order-info {
            background-color: #f9f9f9;
            padding: 15px;
            border-radius: 8px;
            margin-bottom: 20px;
        }

        .split-items {
            margin-bottom: 20px;
        }

        .split-item {
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding: 10px;
            border-bottom: 1px solid #eee;
        }

        .split-item:last-child {
            border-bottom: none;
        }

        .split-group-select {
            padding: 5px;
            border-radius: 4px;
            border: 1px solid #ddd;
        }

        .total-summary {
            margin-top: 20px;
            font-weight: bold;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>订单合并/拆单</h2>

        <?php if (isset($message)) echo $message; ?>

        <div class="tabs">
            <div class="tab active" onclick="switchTab('merge-orders')">合并订单</div>
            <div class="tab" onclick="switchTab('split-order')">拆分订单</div>
        </div>

        <div id="merge-orders" class="tab-content active">
            <h3>待合并订单列表</h3>

            <?php if (empty($pending_orders)): ?>
                <div class="empty-state">
                    <p>当前没有待支付的订单可以合并</p>
                </div>
            <?php else: ?>
                <form method="post" id="merge-form">
                    <input type="hidden" name="action" value="merge_orders">

                    <div class="order-list">
                        <?php foreach ($pending_orders as $order): ?>
                            <div class="order-card">
                                <div class="order-info">
                                    <p><strong>订单号:</strong> <?= htmlspecialchars($order['order_id']); ?></p>
                                    <p><strong>类型:</strong> <?= htmlspecialchars($order['type']); ?></p>
                                    <p><strong>金额:</strong> ¥<?= htmlspecialchars(number_format($order['total_amount'], 2)); ?></p>
                                    <p><strong>创建时间:</strong> <?= htmlspecialchars($order['create_time']); ?></p>
                                    <?php if ($order['table_id']): ?>
                                        <p><strong>餐桌号:</strong> <?= htmlspecialchars($order['table_id']); ?></p>
                                    <?php endif; ?>
                                </div>
                                <div class="order-actions">
                                    <input type="checkbox" name="order_ids[]" value="<?= htmlspecialchars($order['order_id']); ?>" onchange="updateSelectedOrders()">
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>

                    <div class="selected-orders" id="selected-orders-container" style="display: none;">
                        <h3>已选择的订单</h3>
                        <div id="selected-orders-list"></div>
                        <div class="total-summary">
                            总金额: ¥<span id="total-amount">0.00</span>
                        </div>
                        <div style="margin-top: 15px;">
                            <button type="submit" class="btn-primary">合并所选订单</button>
                        </div>
                    </div>
                </form>
            <?php endif; ?>
        </div>

        <div id="split-order" class="tab-content">
            <h3>选择要拆分的订单</h3>

            <?php if (empty($pending_orders)): ?>
                <div class="empty-state">
                    <p>当前没有待支付的订单可以拆分</p>
                </div>
            <?php else: ?>
                <form method="post" id="load-split-form">
                    <input type="hidden" name="action" value="load_split_order">

                    <div class="order-list">
                        <?php foreach ($pending_orders as $order): ?>
                            <?php if ($order['dish_count'] > 1): // 只有多个菜品的订单才能拆分 
                            ?>
                                <div class="order-card">
                                    <div class="order-info">
                                        <p><strong>订单号:</strong> <?= htmlspecialchars($order['order_id']); ?></p>
                                        <p><strong>类型:</strong> <?= htmlspecialchars($order['type']); ?></p>
                                        <p><strong>金额:</strong> ¥<?= htmlspecialchars(number_format($order['total_amount'], 2)); ?></p>
                                        <p><strong>菜品数量:</strong> <?= htmlspecialchars($order['dish_count']); ?></p>
                                        <p><strong>创建时间:</strong> <?= htmlspecialchars($order['create_time']); ?></p>
                                        <?php if ($order['table_id']): ?>
                                            <p><strong>餐桌号:</strong> <?= htmlspecialchars($order['table_id']); ?></p>
                                        <?php endif; ?>
                                    </div>
                                    <div class="order-actions">
                                        <button type="submit" name="order_id" value="<?= htmlspecialchars($order['order_id']); ?>" class="btn-secondary">选择此订单</button>
                                    </div>
                                </div>
                            <?php endif; ?>
                        <?php endforeach; ?>
                    </div>
                </form>

                <?php if ($split_order): ?>
                    <div class="split-container">
                        <div class="split-order-info">
                            <h3>拆分订单: <?= htmlspecialchars($split_order['order_id']); ?></h3>
                            <p><strong>类型:</strong> <?= htmlspecialchars($split_order['type']); ?></p>
                            <p><strong>总金额:</strong> ¥<?= htmlspecialchars(number_format($split_order['total_amount'], 2)); ?></p>
                            <p><strong>创建时间:</strong> <?= htmlspecialchars($split_order['create_time']); ?></p>
                            <?php if ($split_order['table_id']): ?>
                                <p><strong>餐桌号:</strong> <?= htmlspecialchars($split_order['table_id']); ?></p>
                            <?php endif; ?>
                        </div>

                        <form method="post" id="split-form">
                            <input type="hidden" name="action" value="split_order">
                            <input type="hidden" name="order_id" value="<?= htmlspecialchars($split_order['order_id']); ?>">

                            <h4>请为每个菜品选择分组</h4>
                            <div class="split-items">
                                <?php
                                // 按类别分组显示菜品
                                $grouped_items = [];
                                foreach ($split_items as $item) {
                                    $grouped_items[$item['category']][] = $item;
                                }

                                $item_index = 0;
                                foreach ($grouped_items as $category => $category_items):
                                ?>
                                    <div class="category-section">
                                        <div class="category-title"><?= htmlspecialchars($category); ?></div>
                                        <?php foreach ($category_items as $item): ?>
                                            <div class="split-item">
                                                <div>
                                                    <span><?= htmlspecialchars($item['name']); ?> x <?= htmlspecialchars($item['quantity']); ?></span>
                                                    <span>(¥<?= htmlspecialchars(number_format($item['price'], 2)); ?>/份)</span>
                                                </div>
                                                <div>
                                                    <select name="split_groups[<?= $item_index; ?>]" class="split-group-select" onchange="updateSplitGroups()">
                                                        <option value="">请选择分组</option>
                                                        <option value="1">分组 1</option>
                                                        <option value="2">分组 2</option>
                                                        <option value="3">分组 3</option>
                                                        <option value="4">分组 4</option>
                                                    </select>
                                                </div>
                                            </div>
                                            <?php $item_index++; ?>
                                        <?php endforeach; ?>
                                    </div>
                                <?php endforeach; ?>
                            </div>

                            <div id="split-summary" style="display: none;">
                                <h4>拆分后的订单预览</h4>
                                <div id="split-groups-preview"></div>
                                <div style="margin-top: 15px;">
                                    <button type="submit" class="btn-primary">确认拆分</button>
                                </div>
                            </div>
                        </form>
                    </div>
                <?php endif; ?>
            <?php endif; ?>
        </div>
    </div>

    <script>
        function switchTab(tabId) {
            // 隐藏所有标签内容
            document.querySelectorAll('.tab-content').forEach(function(content) {
                content.classList.remove('active');
            });

            // 取消所有标签的活动状态
            document.querySelectorAll('.tab').forEach(function(tab) {
                tab.classList.remove('active');
            });

            // 显示选中的标签内容
            document.getElementById(tabId).classList.add('active');

            // 设置选中标签的活动状态
            document.querySelector('.tab[onclick="switchTab(\'' + tabId + '\')"]').classList.add('active');
        }

        // 更新已选择的订单列表
        function updateSelectedOrders() {
            const selectedOrders = document.querySelectorAll('input[name="order_ids[]"]:checked');
            const container = document.getElementById('selected-orders-container');
            const list = document.getElementById('selected-orders-list');
            const totalAmount = document.getElementById('total-amount');

            if (selectedOrders.length > 0) {
                container.style.display = 'block';
                list.innerHTML = '';

                let total = 0;
                selectedOrders.forEach(function(checkbox) {
                    const orderCard = checkbox.closest('.order-card');
                    const orderInfo = orderCard.querySelector('.order-info');
                    const orderIdText = orderInfo.querySelector('p:first-child').textContent;
                    const amountText = orderInfo.querySelector('p:nth-child(3)').textContent;

                    const orderId = orderIdText.split(':')[1].trim();
                    const amount = parseFloat(amountText.split('¥')[1].trim().replace(',', ''));

                    const item = document.createElement('div');
                    item.className = 'selected-order-item';
                    item.innerHTML = `
                        <div>${orderId}</div>
                        <div>¥${amount.toFixed(2)}</div>
                    `;
                    list.appendChild(item);

                    total += amount;
                });

                totalAmount.textContent = total.toFixed(2);
            } else {
                container.style.display = 'none';
            }
        }

        // 更新拆分组预览
        function updateSplitGroups() {
            const selects = document.querySelectorAll('.split-group-select');
            const preview = document.getElementById('split-groups-preview');
            const summary = document.getElementById('split-summary');

            // 检查是否至少有一个菜品被分配
            let hasAssigned = false;
            const groups = {};

            selects.forEach(function(select, index) {
                const group = select.value;
                if (group) {
                    hasAssigned = true;

                    if (!groups[group]) {
                        groups[group] = {
                            items: [],
                            total: 0
                        };
                    }

                    const item = select.closest('.split-item');
                    const itemText = item.querySelector('div:first-child').textContent;
                    const priceMatch = itemText.match(/¥([\d,.]+)\/份/);
                    const quantityMatch = itemText.match(/x\s*(\d+)/);

                    if (priceMatch && quantityMatch) {
                        const price = parseFloat(priceMatch[1].replace(',', ''));
                        const quantity = parseInt(quantityMatch[1]);
                        const itemTotal = price * quantity;

                        groups[group].items.push({
                            text: itemText,
                            total: itemTotal
                        });

                        groups[group].total += itemTotal;
                    }
                }
            });

            if (hasAssigned) {
                summary.style.display = 'block';
                preview.innerHTML = '';

                // 检查是否至少有两个组
                const groupCount = Object.keys(groups).length;
                if (groupCount < 2) {
                    preview.innerHTML = '<div class="error">请至少将菜品分配到两个不同的组</div>';
                    return;
                }

                for (const group in groups) {
                    const groupDiv = document.createElement('div');
                    groupDiv.className = 'category-section';
                    groupDiv.innerHTML = `
                        <div class="category-title">分组 ${group} (总计: ¥${groups[group].total.toFixed(2)})</div>
                        <div class="category-dishes">
                            ${groups[group].items.map(item => `
                                <div class="split-item">
                                    <div>${item.text}</div>
                                    <div>¥${item.total.toFixed(2)}</div>
                                </div>
                            `).join('')}
                        </div>
                    `;
                    preview.appendChild(groupDiv);
                }
            } else {
                summary.style.display = 'none';
            }
        }

        // 初始化
        document.addEventListener('DOMContentLoaded', function() {
            // 如果有拆分订单，初始化拆分组预览
            if (document.getElementById('split-form')) {
                updateSplitGroups();
            }
        });
    </script>
</body>

</html>