<?php
require_once '../config.php';


// 处理订单状态更新
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action'])) {
    $order_id = $_POST['order_id'] ?? '';
    $dish_id = $_POST['dish_id'] ?? '';
    $new_status = $_POST['new_status'] ?? '';
    $message = '';

    try {
        $pdo->beginTransaction();

        if ($_POST['action'] === 'update_dish_status') {
            // 更新订单详情状态
            $stmt = $pdo->prepare("UPDATE order_details SET status = ? WHERE order_id = ? AND dish_id = ?");
            $stmt->execute([$new_status, $order_id, $dish_id]);

            // 检查该订单的所有菜品是否都已完成
            $stmt = $pdo->prepare("SELECT COUNT(*) FROM order_details WHERE order_id = ? AND status != '已完成'");
            $stmt->execute([$order_id]);
            $pending_count = $stmt->fetchColumn();

            // 如果所有菜品都已完成，更新订单状态为已完成
            if ($pending_count == 0) {
                $stmt = $pdo->prepare("UPDATE orders SET status = '已完成' WHERE order_id = ?");
                $stmt->execute([$order_id]);

                // 如果是堂食订单，检查是否需要释放餐桌
                $stmt = $pdo->prepare("SELECT table_id, type FROM orders WHERE order_id = ?");
                $stmt->execute([$order_id]);
                $order = $stmt->fetch();

                if ($order && $order['type'] === '堂食' && $order['table_id']) {
                    // 这里不自动释放餐桌，因为客人可能还在用餐
                    // 餐桌释放应该在结账时进行
                }
            } else if ($new_status === '制作中' && $pending_count > 0) {
                // 如果有菜品状态变为制作中，更新订单状态为进行中
                $stmt = $pdo->prepare("UPDATE orders SET status = '进行中' WHERE order_id = ?");
                $stmt->execute([$order_id]);
            }

            // 更新厨房订单状态
            $stmt = $pdo->prepare("UPDATE kitchen_orders SET status = ? WHERE order_id = ?");
            $stmt->execute([$new_status, $order_id]);

            $message = "<div class='alert'>菜品状态已更新为: " . htmlspecialchars($new_status) . "</div>";
        }

        $pdo->commit();
    } catch (Exception $e) {
        $pdo->rollBack();
        $message = "<div class='error'>更新失败: " . htmlspecialchars($e->getMessage()) . "</div>";
    }
}

// 获取所有待处理和进行中的订单
$stmt = $pdo->query("SELECT o.order_id, o.user_id, o.table_id, o.type, o.status, o.total_amount, o.create_time, 
                     (SELECT COUNT(*) FROM order_details WHERE order_id = o.order_id) as dish_count
                     FROM orders o 
                     WHERE o.status IN ('待支付', '进行中') 
                     ORDER BY o.create_time DESC");
$orders = $stmt->fetchAll();

// 获取所有菜品类别，用于分类显示
$stmt = $pdo->query("SELECT DISTINCT category FROM dishes ORDER BY category");
$categories = $stmt->fetchAll(PDO::FETCH_COLUMN);
?>

<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <title>实时订单处理</title>
    <link rel="stylesheet" href="style.css">
    <style>
        .order-card {
            border: 1px solid #ddd;
            border-radius: 8px;
            margin-bottom: 20px;
            padding: 15px;
            background-color: #fff;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        }

        .order-header {
            display: flex;
            justify-content: space-between;
            border-bottom: 1px solid #eee;
            padding-bottom: 10px;
            margin-bottom: 10px;
        }

        .order-details {
            margin-top: 15px;
        }

        .dish-item {
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding: 8px 0;
            border-bottom: 1px dashed #eee;
        }

        .dish-actions {
            display: flex;
            gap: 10px;
        }

        .tabs {
            display: flex;
            border-bottom: 1px solid #ddd;
            margin-bottom: 20px;
        }

        .tab {
            padding: 10px 20px;
            cursor: pointer;
            border: 1px solid transparent;
        }

        .tab.active {
            border: 1px solid #ddd;
            border-bottom-color: #fff;
            border-radius: 4px 4px 0 0;
            margin-bottom: -1px;
            background-color: #fff;
        }

        .tab-content {
            display: none;
        }

        .tab-content.active {
            display: block;
        }

        .category-section {
            margin-bottom: 30px;
        }

        .category-title {
            font-size: 18px;
            font-weight: bold;
            margin-bottom: 10px;
            padding-bottom: 5px;
            border-bottom: 2px solid #3498db;
        }

        .refresh-btn {
            background-color: #3498db;
            color: white;
            border: none;
            padding: 8px 15px;
            border-radius: 4px;
            cursor: pointer;
            margin-bottom: 20px;
        }

        .refresh-btn:hover {
            background-color: #2980b9;
        }

        .order-type-tag {
            display: inline-block;
            padding: 3px 8px;
            border-radius: 4px;
            font-size: 12px;
            margin-left: 10px;
        }

        .order-type-堂食 {
            background-color: #3498db;
            color: white;
        }

        .order-type-外带 {
            background-color: #e67e22;
            color: white;
        }

        .order-type-外卖 {
            background-color: #9b59b6;
            color: white;
        }

        .auto-refresh {
            display: flex;
            align-items: center;
            margin-bottom: 20px;
        }

        .auto-refresh label {
            margin-right: 10px;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>实时订单处理</h2>

        <?php if (isset($message)) echo $message; ?>

        <div class="auto-refresh">
            <label for="auto-refresh-toggle">
                <input type="checkbox" id="auto-refresh-toggle" checked> 自动刷新 (30秒)
            </label>
            <button class="refresh-btn" onclick="location.reload()">立即刷新</button>
        </div>

        <div class="tabs">
            <div class="tab active" onclick="switchTab('all-orders')">所有订单</div>
            <div class="tab" onclick="switchTab('kitchen-orders')">厨房订单</div>
            <div class="tab" onclick="switchTab('beverage-orders')">饮品订单</div>
        </div>

        <div id="all-orders" class="tab-content active">
            <?php if (empty($orders)): ?>
                <div class="empty-state">
                    <p>当前没有待处理或进行中的订单</p>
                </div>
            <?php else: ?>
                <?php foreach ($orders as $order): ?>
                    <div class="order-card">
                        <div class="order-header">
                            <div>
                                <strong>订单号: <?= htmlspecialchars($order['order_id']); ?></strong>
                                <span class="order-type-tag order-type-<?= htmlspecialchars($order['type']); ?>"><?= htmlspecialchars($order['type']); ?></span>
                            </div>
                            <div>
                                <span class="status-tag <?= htmlspecialchars($order['status']); ?>"><?= htmlspecialchars($order['status']); ?></span>
                                <?php if ($order['table_id']): ?>
                                    <span>餐桌: <?= htmlspecialchars($order['table_id']); ?></span>
                                <?php endif; ?>
                            </div>
                        </div>
                        <div>
                            <p>创建时间: <?= htmlspecialchars($order['create_time']); ?></p>
                            <p>菜品数量: <?= htmlspecialchars($order['dish_count']); ?></p>
                            <p>总金额: ¥<?= htmlspecialchars(number_format($order['total_amount'], 2)); ?></p>
                        </div>
                        <div class="order-details">
                            <h4>订单详情</h4>
                            <?php
                            // 获取订单详情
                            $stmt = $pdo->prepare("SELECT od.dish_id, d.name, d.category, od.quantity, od.price, od.status 
                                                  FROM order_details od 
                                                  JOIN dishes d ON od.dish_id = d.dish_id 
                                                  WHERE od.order_id = ? 
                                                  ORDER BY d.category, d.name");
                            $stmt->execute([$order['order_id']]);
                            $dishes = $stmt->fetchAll();

                            // 按类别分组显示菜品
                            $grouped_dishes = [];
                            foreach ($dishes as $dish) {
                                $grouped_dishes[$dish['category']][] = $dish;
                            }

                            foreach ($grouped_dishes as $category => $category_dishes):
                            ?>
                                <div class="category-section">
                                    <div class="category-title"><?= htmlspecialchars($category); ?></div>
                                    <?php foreach ($category_dishes as $dish): ?>
                                        <div class="dish-item">
                                            <div>
                                                <span><?= htmlspecialchars($dish['name']); ?> x <?= htmlspecialchars($dish['quantity']); ?></span>
                                                <span>(¥<?= htmlspecialchars(number_format($dish['price'], 2)); ?>/份)</span>
                                            </div>
                                            <div class="dish-actions">
                                                <span class="status-tag <?= htmlspecialchars($dish['status']); ?>"><?= htmlspecialchars($dish['status']); ?></span>
                                                <form method="post" style="display: inline;">
                                                    <input type="hidden" name="action" value="update_dish_status">
                                                    <input type="hidden" name="order_id" value="<?= htmlspecialchars($order['order_id']); ?>">
                                                    <input type="hidden" name="dish_id" value="<?= htmlspecialchars($dish['dish_id']); ?>">
                                                    <?php if ($dish['status'] === '等待中'): ?>
                                                        <input type="hidden" name="new_status" value="制作中">
                                                        <button type="submit" class="btn-link">开始制作</button>
                                                    <?php elseif ($dish['status'] === '制作中'): ?>
                                                        <input type="hidden" name="new_status" value="已完成">
                                                        <button type="submit" class="btn-link">完成</button>
                                                    <?php endif; ?>
                                                </form>
                                            </div>
                                        </div>
                                    <?php endforeach; ?>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                <?php endforeach; ?>
            <?php endif; ?>
        </div>

        <div id="kitchen-orders" class="tab-content">
            <!-- 厨房订单内容 -->
            <?php
            // 过滤出厨房订单（非饮品类）
            $kitchen_orders = [];
            foreach ($orders as $order) {
                $stmt = $pdo->prepare("SELECT COUNT(*) FROM order_details od 
                                      JOIN dishes d ON od.dish_id = d.dish_id 
                                      WHERE od.order_id = ? AND d.category NOT IN ('饮品', '酒水')");
                $stmt->execute([$order['order_id']]);
                $has_kitchen_items = $stmt->fetchColumn() > 0;

                if ($has_kitchen_items) {
                    $kitchen_orders[] = $order;
                }
            }

            if (empty($kitchen_orders)):
            ?>
                <div class="empty-state">
                    <p>当前没有厨房订单</p>
                </div>
            <?php else: ?>
                <?php foreach ($kitchen_orders as $order): ?>
                    <div class="order-card">
                        <div class="order-header">
                            <div>
                                <strong>订单号: <?= htmlspecialchars($order['order_id']); ?></strong>
                                <span class="order-type-tag order-type-<?= htmlspecialchars($order['type']); ?>"><?= htmlspecialchars($order['type']); ?></span>
                            </div>
                            <div>
                                <span class="status-tag <?= htmlspecialchars($order['status']); ?>"><?= htmlspecialchars($order['status']); ?></span>
                                <?php if ($order['table_id']): ?>
                                    <span>餐桌: <?= htmlspecialchars($order['table_id']); ?></span>
                                <?php endif; ?>
                            </div>
                        </div>
                        <div class="order-details">
                            <h4>厨房菜品</h4>
                            <?php
                            // 获取厨房菜品
                            $stmt = $pdo->prepare("SELECT od.dish_id, d.name, d.category, od.quantity, od.price, od.status 
                                                  FROM order_details od 
                                                  JOIN dishes d ON od.dish_id = d.dish_id 
                                                  WHERE od.order_id = ? AND d.category NOT IN ('饮品', '酒水') 
                                                  ORDER BY d.category, d.name");
                            $stmt->execute([$order['order_id']]);
                            $dishes = $stmt->fetchAll();

                            // 按类别分组显示菜品
                            $grouped_dishes = [];
                            foreach ($dishes as $dish) {
                                $grouped_dishes[$dish['category']][] = $dish;
                            }

                            foreach ($grouped_dishes as $category => $category_dishes):
                            ?>
                                <div class="category-section">
                                    <div class="category-title"><?= htmlspecialchars($category); ?></div>
                                    <?php foreach ($category_dishes as $dish): ?>
                                        <div class="dish-item">
                                            <div>
                                                <span><?= htmlspecialchars($dish['name']); ?> x <?= htmlspecialchars($dish['quantity']); ?></span>
                                            </div>
                                            <div class="dish-actions">
                                                <span class="status-tag <?= htmlspecialchars($dish['status']); ?>"><?= htmlspecialchars($dish['status']); ?></span>
                                                <form method="post" style="display: inline;">
                                                    <input type="hidden" name="action" value="update_dish_status">
                                                    <input type="hidden" name="order_id" value="<?= htmlspecialchars($order['order_id']); ?>">
                                                    <input type="hidden" name="dish_id" value="<?= htmlspecialchars($dish['dish_id']); ?>">
                                                    <?php if ($dish['status'] === '等待中'): ?>
                                                        <input type="hidden" name="new_status" value="制作中">
                                                        <button type="submit" class="btn-link">开始制作</button>
                                                    <?php elseif ($dish['status'] === '制作中'): ?>
                                                        <input type="hidden" name="new_status" value="已完成">
                                                        <button type="submit" class="btn-link">完成</button>
                                                    <?php endif; ?>
                                                </form>
                                            </div>
                                        </div>
                                    <?php endforeach; ?>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                <?php endforeach; ?>
            <?php endif; ?>
        </div>

        <div id="beverage-orders" class="tab-content">
            <!-- 饮品订单内容 -->
            <?php
            // 过滤出饮品订单
            $beverage_orders = [];
            foreach ($orders as $order) {
                $stmt = $pdo->prepare("SELECT COUNT(*) FROM order_details od 
                                      JOIN dishes d ON od.dish_id = d.dish_id 
                                      WHERE od.order_id = ? AND d.category IN ('饮品', '酒水')");
                $stmt->execute([$order['order_id']]);
                $has_beverage_items = $stmt->fetchColumn() > 0;

                if ($has_beverage_items) {
                    $beverage_orders[] = $order;
                }
            }

            if (empty($beverage_orders)):
            ?>
                <div class="empty-state">
                    <p>当前没有饮品订单</p>
                </div>
            <?php else: ?>
                <?php foreach ($beverage_orders as $order): ?>
                    <div class="order-card">
                        <div class="order-header">
                            <div>
                                <strong>订单号: <?= htmlspecialchars($order['order_id']); ?></strong>
                                <span class="order-type-tag order-type-<?= htmlspecialchars($order['type']); ?>"><?= htmlspecialchars($order['type']); ?></span>
                            </div>
                            <div>
                                <span class="status-tag <?= htmlspecialchars($order['status']); ?>"><?= htmlspecialchars($order['status']); ?></span>
                                <?php if ($order['table_id']): ?>
                                    <span>餐桌: <?= htmlspecialchars($order['table_id']); ?></span>
                                <?php endif; ?>
                            </div>
                        </div>
                        <div class="order-details">
                            <h4>饮品</h4>
                            <?php
                            // 获取饮品
                            $stmt = $pdo->prepare("SELECT od.dish_id, d.name, d.category, od.quantity, od.price, od.status 
                                                  FROM order_details od 
                                                  JOIN dishes d ON od.dish_id = d.dish_id 
                                                  WHERE od.order_id = ? AND d.category IN ('饮品', '酒水') 
                                                  ORDER BY d.category, d.name");
                            $stmt->execute([$order['order_id']]);
                            $dishes = $stmt->fetchAll();

                            // 按类别分组显示菜品
                            $grouped_dishes = [];
                            foreach ($dishes as $dish) {
                                $grouped_dishes[$dish['category']][] = $dish;
                            }

                            foreach ($grouped_dishes as $category => $category_dishes):
                            ?>
                                <div class="category-section">
                                    <div class="category-title"><?= htmlspecialchars($category); ?></div>
                                    <?php foreach ($category_dishes as $dish): ?>
                                        <div class="dish-item">
                                            <div>
                                                <span><?= htmlspecialchars($dish['name']); ?> x <?= htmlspecialchars($dish['quantity']); ?></span>
                                            </div>
                                            <div class="dish-actions">
                                                <span class="status-tag <?= htmlspecialchars($dish['status']); ?>"><?= htmlspecialchars($dish['status']); ?></span>
                                                <form method="post" style="display: inline;">
                                                    <input type="hidden" name="action" value="update_dish_status">
                                                    <input type="hidden" name="order_id" value="<?= htmlspecialchars($order['order_id']); ?>">
                                                    <input type="hidden" name="dish_id" value="<?= htmlspecialchars($dish['dish_id']); ?>">
                                                    <?php if ($dish['status'] === '等待中'): ?>
                                                        <input type="hidden" name="new_status" value="制作中">
                                                        <button type="submit" class="btn-link">开始制作</button>
                                                    <?php elseif ($dish['status'] === '制作中'): ?>
                                                        <input type="hidden" name="new_status" value="已完成">
                                                        <button type="submit" class="btn-link">完成</button>
                                                    <?php endif; ?>
                                                </form>
                                            </div>
                                        </div>
                                    <?php endforeach; ?>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                <?php endforeach; ?>
            <?php endif; ?>
        </div>
    </div>

    <script>
        function switchTab(tabId) {
            // 隐藏所有标签内容
            document.querySelectorAll('.tab-content').forEach(function(content) {
                content.classList.remove('active');
            });

            // 取消所有标签的活动状态
            document.querySelectorAll('.tab').forEach(function(tab) {
                tab.classList.remove('active');
            });

            // 显示选中的标签内容
            document.getElementById(tabId).classList.add('active');

            // 设置选中标签的活动状态
            document.querySelector('.tab[onclick="switchTab(\'' + tabId + '\')"]').classList.add('active');
        }

        // 自动刷新功能
        let refreshInterval;
        const toggleCheckbox = document.getElementById('auto-refresh-toggle');

        function startAutoRefresh() {
            refreshInterval = setInterval(function() {
                location.reload();
            }, 30000); // 30秒刷新一次
        }

        function stopAutoRefresh() {
            clearInterval(refreshInterval);
        }

        toggleCheckbox.addEventListener('change', function() {
            if (this.checked) {
                startAutoRefresh();
            } else {
                stopAutoRefresh();
            }
        });

        // 初始化自动刷新
        if (toggleCheckbox.checked) {
            startAutoRefresh();
        }
    </script>
</body>

</html>