<?php
require __DIR__ . '/config.php';

// 自动保留最近7天备份
$backup_dir = __DIR__ . '/backups/';
$expire_days = 7;

try {
    // 创建新备份
    $filename = 'auto_backup_' . date('YmdHis') . '.sql';
    $full_path = $backup_dir . $filename;
    // 保持原有备份命令不变
    $mysqldump_path = '"' . MYSQLDUMP_PATH . '"'; // 路径用双引号包裹，兼容空格
    $command = "{$mysqldump_path} -u" . DB_USER . " -p\"" . DB_PASS . "\" " . DB_NAME . " > \"{$full_path}\" 2>&1";
    exec($command, $output, $result);

    if ($result !== 0) {
        throw new Exception("自动备份失败");
    }

    // 记录数据库
    $file_size = filesize($full_path);
    $pdo->prepare("
        INSERT INTO backup_logs 
        (filename, file_size, employee_id)
        VALUES (?, ?, 0)
    ")->execute([$filename, $file_size]);

    // 记录系统日志
    log_action('system', '自动备份', "创建自动备份: $filename", 'backup');

    // 清理旧备份
    $files = glob($backup_dir . 'auto_backup_*');
    $now = time();
    foreach ($files as $file) {
        if (is_file($file)) {
            if ($now - filemtime($file) >= $expire_days * 86400) {
                unlink($file);
                $pdo->prepare("
                    DELETE FROM backup_logs 
                    WHERE filename = ?
                ")->execute([basename($file)]);
                log_action('system', '清理备份', "删除过期备份: ".basename($file), 'backup');
            }
        }
    }
} catch (Exception $e) {
    log_action('system', '自动备份错误', $e->getMessage(), 'backup');
}