<?php
session_start();
require '../config.php';

// 权限验证（适配当前数据库）
if ($_SESSION['role'] !== 'admin') {
    header("Location: ../home.php");
    exit;
}

// 备份目录配置（保持原样）
$backup_dir = __DIR__ . '/../backups/';
if (!file_exists($backup_dir)) mkdir($backup_dir, 0755, true);

// 执行手动备份（修改数据库部分）
if (isset($_GET['action'])) {
    switch ($_GET['action']) {
        case 'backup':
            $filename = 'backup_' . date('YmdHis') . '.sql';
            $full_path = $backup_dir . $filename;

            try {
                // 验证员工会话（修改点1）
                if (!isset($_SESSION['employee_id'])) {
                    throw new Exception("用户未登录");
                }
                $operator_id = $_SESSION['employee_id'];

                // 保持原有备份命令不变
                $mysqldump_path = '"' . MYSQLDUMP_PATH . '"'; // 路径用双引号包裹，兼容空格
                $command = "{$mysqldump_path} -u" . DB_USER . " -p\"" . DB_PASS . "\" " . DB_NAME . " > \"{$full_path}\" 2>&1";
                exec($command, $output, $result);

                if ($result !== 0) {
                    throw new Exception("备份失败，错误码: $result");
                }

                // 等待文件写入（保持原样）
                $max_retries = 10;
                do {
                    clearstatcache(true, $full_path);
                    $file_size = filesize($full_path);
                    if ($file_size > 0) break;
                    usleep(500000);
                } while ($max_retries-- > 0);

                if ($file_size === 0) {
                    throw new Exception("文件写入失败");
                }

                // 修改点2：验证员工存在性
                $stmt = $pdo->prepare("SELECT employee_id FROM employees WHERE employee_id = ?");
                $stmt->execute([$operator_id]);
                if (!$stmt->fetch()) {
                    throw new Exception("操作员不存在: $operator_id");
                }

                // 修改点3：插入备份记录到新表
                $insertStmt = $pdo->prepare("
                    INSERT INTO backup_logs (filename, file_size, employee_id)
                    VALUES (?, ?, ?)
                ");
                if (!$insertStmt->execute([$filename, $file_size, $operator_id])) {
                    throw new Exception("备份记录保存失败");
                }

                // 新增日志记录（保持原有结构新增）
                log_action('system', '数据备份', "创建备份文件: $filename", 'backup');

                $_SESSION['success'] = "备份成功: $filename";
            } catch (Exception $e) {
                $_SESSION['error'] = $e->getMessage();
                log_action('system', '备份错误', $e->getMessage(), 'backup');
            }
            header("Location: data_security.php");
            exit;

        case 'delete':
            $file = basename($_GET['file']);
            $file_path = $backup_dir . $file;

            try {
                if (!file_exists($file_path)) {
                    throw new Exception("文件不存在: $file");
                }
                if (!unlink($file_path)) {
                    throw new Exception("文件删除失败");
                }

                // 修改点4：删除新表记录
                $deleteStmt = $pdo->prepare("DELETE FROM backup_logs WHERE filename = ?");
                $deleteStmt->execute([$file]);

                // 新增日志记录
                log_action('system', '数据删除', "删除备份文件: $file", 'backup');

                $_SESSION['success'] = "删除成功: $file";
            } catch (Exception $e) {
                $_SESSION['error'] = $e->getMessage();
                log_action('system', '删除错误', $e->getMessage(), 'backup');
            }
            header("Location: data_security.php");
            exit;
    }
}

// 修改点5：获取备份列表（适配新表）
$backups = $pdo->query("
    SELECT 
        bl.*,
        e.username AS operator_name
    FROM backup_logs bl
    LEFT JOIN employees e ON bl.employee_id = e.employee_id
    ORDER BY bl.created_at DESC
")->fetchAll();

// 保持HTML结构和样式完全不变
?>
<!DOCTYPE html>
<html>

<head>
    <title>数据安全管理</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        /* 悬浮提示样式 */
        td[title]:hover::after {
            content: attr(title);
            position: absolute;
            background: #fff;
            border: 1px solid #ddd;
            padding: 5px;
            margin-top: 20px;
            z-index: 100;
        }

        .btn-delete {

            background: #dc3545;
            padding: 4px 8px;
            border-radius: 4px;
            color: white;
            white-space: nowrap;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>数据备份管理</h2>
        <?php
        // 在 <div class="container"> 内部添加
        if (isset($_SESSION['success'])) {
            echo '<div class="alert alert-success">' . $_SESSION['success'] . '</div>';
            unset($_SESSION['success']);
        }
        if (isset($_SESSION['error'])) {
            echo '<div class="alert alert-error">' . $_SESSION['error'] . '</div>';
            unset($_SESSION['error']);
        }
        ?>
        <div class="card">
            <div class="toolbar">
                <a href="data_security.php?action=backup"
                    class="btn-primary"
                    onclick="return confirm('确认执行手动备份？')">
                    立即备份
                </a>
                <span>自动备份每日03:00执行（保留最近7天）</span>
            </div>

            <div class="table-container">
                <table>
                    <thead>
                        <tr>
                            <th>备份文件</th>
                            <th>大小</th>
                            <th>备份时间</th>
                            <th>操作人</th>
                            <th>存储路径</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($backups)): ?>
                            <tr>
                                <td colspan="6" class="empty-notice">暂无备份记录</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($backups as $b): ?>
                                <tr>
                                    <td><?= htmlspecialchars($b['filename']) ?></td>
                                    <td><?= round($b['file_size'] / 1024) ?>KB</td>
                                    <td><?= date('Y-m-d H:i', strtotime($b['created_at'])) ?></td>
                                    <td><?= htmlspecialchars($_SESSION['username']) ?></td>
                                    <td title="<?= htmlspecialchars($backup_dir . $b['filename']) ?>">
                                        <?php
                                        $full_path = $backup_dir . $b['filename'];
                                        $parts = preg_split('#[\\\/]#', $full_path);
                                        $parts = array_slice($parts, -3);
                                        echo htmlspecialchars(implode('/', $parts));
                                        ?>
                                    </td>
                                    <td>
                                        <?php if (!file_exists($backup_dir . $b['filename'])): ?>
                                            <span class="file-missing">文件丢失</span>
                                        <?php endif; ?>
                                        <a href="data_security.php?action=delete&file=<?= $b['filename'] ?>"
                                            class="btn-delete">删除</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>