<?php
session_start();
require '../config.php';

// 权限验证
if ($_SESSION['role'] !== 'admin') {
    header("Location: ../home.php");
    exit;
}

// 查询参数处理
$search = $_GET['search'] ?? '';
$type = $_GET['type'] ?? '';
$page = max(1, $_GET['page'] ?? 1);
$per_page = 20;

// 构建查询条件
$where = [];
$params = [];

if (!empty($search)) {
    $where[] = "(description LIKE ? OR related_id LIKE ?)";
    $params[] = "%$search%";
    $params[] = "%$search%";
}

if (!empty($type)) {
    $where[] = "log_type = ?";
    $params[] = $type;
}

$where_clause = $where ? 'WHERE ' . implode(' AND ', $where) : '';

// 获取总记录数
$count_stmt = $pdo->prepare("
    SELECT COUNT(*) 
    FROM system_logs
    $where_clause
");
$count_stmt->execute($params);
$total = $count_stmt->fetchColumn();

// 分页数据查询
$offset = ($page - 1) * $per_page;
$query = "
    SELECT 
        l.*,
        e.username AS operator
    FROM system_logs l
    LEFT JOIN employees e ON l.employee_id = e.employee_id
    $where_clause
    ORDER BY created_at DESC
    LIMIT $per_page OFFSET $offset
";

$stmt = $pdo->prepare($query);
$stmt->execute($params);
$logs = $stmt->fetchAll();

// 类型选项
$log_types = ['order' => '订单', 'payment' => '支付', 'action' => '操作','system' => '系统'];
?>
<!DOCTYPE html>
<html>

<head>
    <title>系统日志</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        /* 日志页面特定样式 */
        .filter-card {
            margin-bottom: 20px;
            padding: 15px;
        }

        .filter-group {
            display: inline-block;
            margin-right: 10px;
        }

        .related-link {
            color: #2196F3;
            text-decoration: none;
        }

        .log-desc {
            max-width: 300px;
            word-break: break-all;
        }

        .pagination {
            margin-top: 20px;
            text-align: center;
        }

        .pagination a {
            display: inline-block;
            padding: 5px 10px;
            margin: 0 2px;
            border: 1px solid #ddd;
            border-radius: 3px;
        }

        .pagination .active {
            background: #2196F3;
            color: white;
            border-color: #2196F3;
        }

        .pagination-info {
            color: #666;
            margin-bottom: 10px;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>系统操作日志</h2>

        <!-- 搜索筛选栏 -->
        <div class="card filter-card">
            <form method="get">
                <div class="filter-group">
                    <select name="type" class="form-control">
                        <option value="">所有类型</option>
                        <?php foreach ($log_types as $k => $v): ?>
                            <option value="<?= $k ?>" <?= $type === $k ? 'selected' : '' ?>>
                                <?= $v ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <div class="filter-group">
                    <input type="text"
                        name="search"
                        placeholder="搜索内容或关联ID"
                        value="<?= htmlspecialchars($search) ?>"
                        class="form-control">
                </div>

                <button type="submit" class="btn btn-primary">筛选</button>
            </form>
        </div>

        <!-- 日志列表 -->
        <div class="card">
            <div class="pagination-info">
                共 <?= $total ?> 条记录，当前显示 <?= ($page - 1) * $per_page + 1 ?> - <?= min($page * $per_page, $total) ?>
            </div>

            <table class="data-table">
                <thead>
                    <tr>
                        <th>时间</th>
                        <th>类型</th>
                        <th>操作人员</th>
                        <th>操作类型</th>
                        <th>关联ID</th>
                        <th>详细信息</th>
                        <th>IP地址</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($logs as $log): ?>
                        <tr>
                            <td><?= date('m-d H:i', strtotime($log['created_at'])) ?></td>
                            <td><?= $log_types[$log['log_type']] ?? '未知' ?></td>
                            <td><?= $log['operator'] ?? '系统' ?></td>
                            <td><?= htmlspecialchars($log['action_type']) ?></td>
                            <td>
                                <?php if ($log['related_id']): ?>
                                    <a href="#" class="related-link">
                                        <?= $log['related_id'] ?>
                                    </a>
                                <?php endif; ?>
                            </td>
                            <td class="log-desc">
                                <?= nl2br(htmlspecialchars($log['description'])) ?>
                            </td>
                            <td><?= $log['ip_address'] ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>

            <!-- 分页导航 -->
            <div class="pagination">
                <?php if ($page > 1): ?>
                    <a href="?<?= http_build_query(array_merge($_GET, ['page' => $page - 1])) ?>">上一页</a>
                <?php endif; ?>

                <?php
                $total_pages = ceil($total / $per_page);
                $start = max(1, $page - 2);
                $end = min($total_pages, $page + 2);

                for ($i = $start; $i <= $end; $i++): ?>
                    <a href="?<?= http_build_query(array_merge($_GET, ['page' => $i])) ?>"
                        class="<?= $i == $page ? 'active' : '' ?>">
                        <?= $i ?>
                    </a>
                <?php endfor; ?>

                <?php if ($page < $total_pages): ?>
                    <a href="?<?= http_build_query(array_merge($_GET, ['page' => $page + 1])) ?>">下一页</a>
                <?php endif; ?>
            </div>
        </div>
    </div>
</body>

</html>