<?php
session_start();
require '../config.php';

// 权限验证
if ($_SESSION['role'] !== 'admin') {
    header("Location: ../home.php");
    exit;
}

// 删除员工
if (isset($_GET['delete'])) {
    $employee_id = (int)$_GET['delete'];

    try {
        $pdo->beginTransaction();

        // 删除员工（当前数据库没有关联权限表）
        $pdo->prepare("DELETE FROM employees WHERE employee_id = ?")
            ->execute([$employee_id]);

        $pdo->commit();
        $_SESSION['success'] = "员工删除成功";
        log_action('action','删除员工', "删除员工ID: $employee_id",'delete');
    } catch (PDOException $e) {
        $pdo->rollBack();
        $_SESSION['error'] = "删除失败：" . $e->getMessage();
    }
    header("Location: user_management.php");
    exit;
}

// 获取所有员工
$employees = $pdo->query("
    SELECT 
        employee_id,
        username,
        role,
        DATE_FORMAT(created_at, '%Y-%m-%d') AS reg_date,
        last_login
    FROM employees
    ORDER BY role, username
")->fetchAll();

// 角色映射
$roleMap = [
    'admin'    => '管理员',
    'cashier'  => '收银员',
    'chef'     => '厨师',
    'manager'  => '店长'
];
?>

<!DOCTYPE html>
<html>

<head>
    <title>员工管理</title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h2>系统用户管理</h2>

        <!-- 消息提示 -->
        <?php if (isset($_SESSION['success'])): ?>
            <div class="alert success"><?= $_SESSION['success'] ?></div>
            <?php unset($_SESSION['success']); ?>
        <?php endif; ?>

        <?php if (isset($_SESSION['error'])): ?>
            <div class="alert error"><?= $_SESSION['error'] ?></div>
            <?php unset($_SESSION['error']); ?>
        <?php endif; ?>

        <!-- 新建员工表单 -->
        <div class="card">
            <h3>新建员工</h3>
            <form method="POST" action="user_create.php">
                <div class="form-group">
                    <label>用户名</label>
                    <input type="text" name="username" required
                        pattern="[A-Za-z0-9_]{3,20}"
                        title="3-20位字母、数字或下划线">
                </div>

                <div class="form-group">
                    <label>密码</label>
                    <input type="password" name="password" required minlength="6">
                </div>

                <div class="form-group">
                    <label>角色</label>
                    <select name="role" required>
                        <?php foreach ($roleMap as $value => $label): ?>
                            <option value="<?= $value ?>"><?= $label ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <button type="submit" class="btn-primary">创建员工</button>
            </form>
        </div>

        <!-- 员工列表 -->
        <div class="card">
            <h3>现有员工</h3>
            <table class="data-table">
                <thead>
                    <tr>
                        <th>用户名</th>
                        <th>角色</th>
                        <th>注册日期</th>
                        <th>最后登录</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($employees as $emp): ?>
                        <tr>
                            <td><?= htmlspecialchars($emp['username']) ?></td>
                            <td><?= $roleMap[$emp['role']] ?? '未知角色' ?></td>
                            <td><?= $emp['reg_date'] ?></td>
                            <td>
                                <?= $emp['last_login'] ?
                                    date('Y-m-d H:i', strtotime($emp['last_login'])) :
                                    '从未登录' ?>
                            </td>
                            <td>
                                <a href="user_edit.php?id=<?= $emp['employee_id'] ?>"
                                    class="btn-edit">编辑</a>
                                <a href="user_management.php?delete=<?= $emp['employee_id'] ?>"
                                    onclick="return confirm('确认删除该员工？')"
                                    class="btn-delete">删除</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</body>

</html>